function mu_initialize_models
% invoked by mulab
% This is the general list of available components
% This function creates a 
% global structure MU_COMPONENT
% with fields NAME
% PARAMETER.NUMBER double (integer)
% PARAMETER.NAME cell array
% PARAMETER.TYPE cell array (unlim positive limited)
% It further creates the global MU_TABLE
global MU_COMPONENT
global MU_TABLE
MU_COMPONENT=[]; % reset
MU_TABLE=[];     % reset
MU_TABLE.GAMU=0.01355; % MHz/G
MU_TABLE.TAUMU=2197.03; % ns
MU_TABLE.GAME=2.8025; % MHz/G
MU_COMPONENT.NAME={'da'};
MU_COMPONENT.PARAMETER.NUMBER=1;
MU_COMPONENT.PARAMETER.NAME={'lpha'};
MU_COMPONENT.PARAMETER.STEPBOUNDS=[0.01 0 0]; % step lobound hibound
                                              % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION={'mudalpha(p,data)'}; % name of called function
MU_COMPONENT.HELP={'alpha correction'}; % help string
% correction factor, not a component
MU_COMPONENT.NAME(2)={'ba'};  % decaying amplitude, lorentzian or gaussian
MU_COMPONENT.PARAMETER(2).NUMBER=3;
MU_COMPONENT.PARAMETER(2).NAME={'Amp','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(2).STEPBOUNDS=[0.01 0 0; ...
                    0.1 0 0; 0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(2)={'mubackground(p,data)'}; 
MU_COMPONENT.HELP(2)={['Non-precessing component ' ...
                    ' with Lorentzian/Gaussian relaxation']};
MU_COMPONENT.NAME(3)={'mu'};
MU_COMPONENT.PARAMETER(3).NUMBER=5;
MU_COMPONENT.PARAMETER(3).NAME={'Amp','Gau','Phi','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(3).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; 10 0 0; ...
                    0.1 0 0; 0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(3)={'muprecession(p,data)'};
MU_COMPONENT.HELP(3)={['Precessing armonic component ' ...
                    'with Lorentzian/Gaussian relaxation']} ;
MU_COMPONENT.NAME(4)={'bj'};
MU_COMPONENT.PARAMETER(4).NUMBER=5;
MU_COMPONENT.PARAMETER(4).NAME={'Amp','Gau','Phi','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(4).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; 10 0 0; ...
                    0.1 0 0; 0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(4)={'mubessel(p,data)'};
MU_COMPONENT.HELP(4)={['Precessing Bessel J0 component ' ...
                    'with Lorentzian/Gaussian relaxation']} ;
MU_COMPONENT.NAME(5)={'st'};
MU_COMPONENT.PARAMETER(5).NUMBER=5;
MU_COMPONENT.PARAMETER(5).NAME={'Amp','Gau','Phi','DecR','Beta'};
MU_COMPONENT.PARAMETER(5).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; 10 0 0; ...
                    0.1 0.001 1000; 0.1 0.001 1000]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(5)={'mustretched(p,data)'};
MU_COMPONENT.HELP(5)={['Precessing armonic component' ...
                    'with stretched exponential relaxation']} ;
MU_COMPONENT.NAME(6)={'kg'};
MU_COMPONENT.PARAMETER(6).NUMBER=5;
MU_COMPONENT.PARAMETER(6).NAME={'Amp','LFGa','DeG','DeLo','DyNu'};
MU_COMPONENT.PARAMETER(6).STEPBOUNDS=[0.01 0 0; 5 0 0; ...
                    0.1 0.001 1000; 0.1 0.001 1000;...
                   0.001 0 1e5]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(6)={'mukubogau(p,data)'};
MU_COMPONENT.HELP(6)={['Kubo Toyabe suite, Gaussian ' ...
                    'static in zero or longitudinal field, with T1, '...
                    'or dynamic zero field']} ;
MU_COMPONENT.NAME(7)={'kl'};
MU_COMPONENT.PARAMETER(7).NUMBER=4;
MU_COMPONENT.PARAMETER(7).NAME={'Amp','LFGa','DeL','DeLo'};
MU_COMPONENT.PARAMETER(7).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; ...
                    0.1 0.001 1000; 0.1 0.001 1000]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(7)={'mukubolorentz(p,data)'};
MU_COMPONENT.HELP(7)={['Kubo Toyabe suite, Lorentzian ' ...
                    'static in zero or longitudinal field, with T1']} ;

MU_COMPONENT.NAME(8)={'mt'};
MU_COMPONENT.PARAMETER(8).NUMBER=8;
MU_COMPONENT.PARAMETER(8).NAME={'Amp','Hyp','Gau','Phi',...
                    'DeLo','DeGa','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(8).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0 ; 1 0 0; 10 0 0; ...
                    0.1 0 0; 0.1 0 0; 0.1 0 0; 0.1 0 0 ]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(8)={'muoniumtriplet(p,data)'};
MU_COMPONENT.HELP(8)={['Muonium triplet, ' ...
                    'static in transverse field, with independent rates']} ;

MU_COMPONENT.NAME(9)={'fl'};
MU_COMPONENT.PARAMETER(9).NUMBER=6;
MU_COMPONENT.PARAMETER(9).NAME={'Amp','Gau','Phi',...
                    'Lmbd','Xi','DeGa'};
MU_COMPONENT.PARAMETER(9).STEPBOUNDS=[0.01 0 0; ...
                    1 0 1e5; 1 0 0; 1 0 0; ...
                    0.1 0 0; 0.1 0 0]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(9)={'mufll(p,data)'};
MU_COMPONENT.HELP(9)={['Isotropic Flux Line Lattice, ' ...
                    'London approximation, convoluted with Gaussian']} ;
MU_COMPONENT.NAME(10)={'fm'};
MU_COMPONENT.PARAMETER(10).NUMBER=4;
MU_COMPONENT.PARAMETER(10).NAME={'Amp','Gau',...
                    'DeLo','DeGa'};
MU_COMPONENT.PARAMETER(10).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0; 0.1 0 0; 0.1 0 0]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(10)={'mufmuf(p,data)'};
MU_COMPONENT.HELP(10)={['FMuF polycrystal in zero field, ' ...
                    'with decays']} ;
MU_COMPONENT.NAME(11)={'hm'};
MU_COMPONENT.PARAMETER(11).NUMBER=4;
MU_COMPONENT.PARAMETER(11).NAME={'Amp','Gau',...
                    'LDeL','TDeL'}; % amplitude, 
                                    % dipolar field = mu0 gaF gamu h/(4 pi r^3)
                                    % + two lor decays, one for
                                    % constant (longitudinal) and
                                    % one for like precessions (transverse)
MU_COMPONENT.PARAMETER(11).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0; 1 0 0; 0.1 0 0;]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(11)={'mumuh(p,data)'};
MU_COMPONENT.HELP(11)={['MuH polycrystal in zero field, ' ...
                    'with T1, T2 decays']} ;
MU_COMPONENT.NAME(12)={'dm'};
MU_COMPONENT.PARAMETER(12).NUMBER=5;
MU_COMPONENT.PARAMETER(12).NAME={'Amp','Gau',...
                    'NuQ','LDeL','TDeL'}; 
                             % 1 amplitude, 
                             % 2 dipolar field
                             % Bd = mu0 gaF gamu h/(4 pi r^3) (G)
                             % 3 secular quadrupolar frequency 
                             % nu_Q (3 cos^2 beta -1)/4 (kHz)
                             % nu_Q= 3 e Q Vzz /2hS(2S-1) 
                             % with beta = angle between dipolar z axis
                             % and quadrupolar zita axis (eta=0)
                             % + 4 5 two lor decays, one for
                             % constant (longitudinal) and
                             % one for precessions (transverse)
MU_COMPONENT.PARAMETER(12).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0; 0.1 0 0; 0.1 0 0; 0.1 0 0]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(12)={'mumud(p,data)'};
MU_COMPONENT.HELP(12)={['MuD polycrystal in zero field, ' ...
                    'with Bdip, nuQzz and T1, T2 decays']} ;

MU_COMPONENT.NAME(13)={'kt'};
MU_COMPONENT.PARAMETER(13).NUMBER=5;
MU_COMPONENT.PARAMETER(13).NAME={'Amp','LFGa','DeGa','DeLo','DyNu'};
MU_COMPONENT.PARAMETER(13).STEPBOUNDS=[0.01 0 0; 5 0 0; ...
                    0.1 0 0; 0.1 0 0;...
                   0.001 0 1e5]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(13)={'mukt(p,data)'};
MU_COMPONENT.HELP(13)={['Kubo Toyabe suite, static or dynamic, Gaussian or Lorentzian ' ...
                    'in zero or longitudinal field, (default Gaussian)']} ;

