function mufit_gui(varargin)
% usage MUFIT_GUI
%
%  forces the layout of the menu, (rehash)
%
% usage MUFIT_GUI(1)
%
%  simply brings menu window back to focus 
%
% MULAB FIT GUI MENU.
% Main GUI menu for MuLab. 
% IMPORTANT! First check that LOCATION, FILENAME PREFIX and LOG
% PATH are set (see Main MEnu below for details), then choose data
% PATH, then load data, etc. For a primer see:
% http://www.fis.unipr.it/home/roberto.derenzi/dispense/pmwiki.php?n=MuSR.Mulab
%
% Allows selection of 
% FORWARD-BACKWARD GROUP, e.g. 1:4 5 7 in either forward or backward
% selects 1 2 3 4 5 and 7 in that group, to produce asymmetry as
%
%          (NF(t)-alpha*NB(t))/(NF(t)+alpha*NB(t))
% 
% ALPHA, vide supra
% BIN e.g bin 2 means that time bins are rebinned
% in twos (only for plotting purpose, the fit is always performed
% on un(re)binned data) 
% FIT RANGE over which fit is performed. Bin does not count here. 
% Bin 1 means: OFFSET (v. infra) bins from bin T0 (v. infra)
% T0 is the bin where t=0 lies. T0+OFFSET is the first good bin.
% LOAD run via a GUI interface, < and > to load previous or next,
% with respect to the number displayed as NEXT RUN in the input above  
% ADD to add a run to the present one (GUI). <+ and +> to add
% previous or next.
% LDMODEL with empty right input loads a previously performed fit
% (but not its data) with a GUI interface. You can navigate also to
% other directories to load older fit models. You can type a
% conventional model name, e.g. damu (v. infra for syntax), to create an
% empty (damu) fit model
% EDMODEL allows to erase/add/replace (empty) components to the
% present model (e.g. transform the present damu into damumu)
% PATH selects data directory, by means of a GUI interface. The log
% directory may be automatically set according to a convention
% explained in .../pmwiki.php?n=MuSR.MulabPrimer
% MINUIT MODE selects batch or interactive (not working yet) 
% FIT/DATA controls asymmetry definition (whether the denominator
% is fitted or computed from data)
%
% DO FIT Performs FMINUIT best fit with the chosen Initial Guess (v. infra) 
% LOG VERSION is the tag added to the fit summary files. Different
% tags identify different generations of fits with the same general
% model, e.g. damu with Gaussian vs. Lorentzian relaxation rates.
% UPDATE transfers the results of last best fit to the Initial Guess
% PLOTFIT overlays fit and data according to either Initial GUESS
% or Best Fit RESULTS over a different range (right input)
% FFT Performs Fast Fourier Transform of Residues (data minus fit), 
% selectively subtracting components of the present model: 
% selection is done by checking the FFT box at the top left corner
% of each component parameter-list) and they are subtracted
% from the data with the displayed parameter values, prior to 
% processing the fft
% RANGE (MHz) is the FFT display in MHz, and  
% LB (Line Broadening) is the apodizing filter width, in us-1 
%
% FIT PARAMETERS edits parameters (v. primer vel infra for model
% naming). Each parameter belongs to a component. They are all
% numbered consecutively (Minuit external parameter number).
% FFT CHECKBOX select to subtract this component from the data in the
% the fft of the fit residues.
% VALUE the left input sets the initial guess 
% ~!=+ the right input sets the parameter state, according to: 
%      ~ free varying, ! fixed, = shared, + linear relation
% SHARED, e.g. =3 forces this parameter to share its value with parameter 
% number 3, i.e only one Minuit internal parameter will be
% generated for these two. More parameters may share the same value.
% LINEAR RELATIONS e.g. +2.1*p1+0.5*p5 means that this parameter is
% forced to take the value given by the expression, where p1, p5
% stand for parameter 1 and 5 n the list, respectively
% PLOT selects for parameter plots, with 1, 2, 3 or 4 subplots. 
% Parameter plot is performed from the main dropodown menu PLOTS,
% either vs T, or B (nominal values), or user defined x (see primer). 
% The local dropdown selects in which subplot the parameter is
% plotted (0 ignored),  
%
% Model components (use lowercase!) are defined in
% MU_INITIALIZE_MODELS (try TYPE MU_INITIALIZE_MODELS) as:
% DA alpha correction, in linear approximation
%    dalpha, to get a better approx ALPHA_n+1=ALPHA_n-DALPHA
% BA pure decay, A*exp(-t*L)*exp(-(t*S)^2/2), with parameters
%    A=baAmp asymmetry, unlimited (-infinity < A < infinity)
%    L=baDeLo Lorentzian rate, unlim
%    S=baDeGa Gaussian rate, unlim
% MU "wiggles", A*cos(g*B-P)*exp(-t*L)*exp(-(t*S)^2/2) with
%    A=muAmp asymmetry, unlim
%    B=muGau field (Gauss), unlim (g=2*pi*gamma_mu)
%    P=muPhi phase (degree), unlim
%    L=muDeLo Lorentzian rate (us-1), unlim
%    S=muDeGa Gaussian rate (us-1), unlim
% BJ Bessel J0, A*J0(g*B-P)*exp(-t*L)*exp(-(t*S)^2/2)
%    A=bjAmp asymmetry, unlim
%    B=bjGau field (Gauss), unlim (g=2*pi*gamma_mu)
%    P=bjPhi phase (degree), unlim
%    L=bjDeLo Lorentzian rate (us-1), unlim
%    S=bjDeGa Gaussian rate (us-1), unlim
% ST Stretched, A*cos(g*B-P)*exp(-(t*L)^K)
%    A=stAmp asymmetry, unlim
%    B=stGau field (Gauss), unlim (g=2*pi*gamma_mu)
%    P=stPhi phase (degree), unlim
%    L=stDecR decay rate (us-1), 1e-3<=L<=1e3
%    K=stBeta Gaussian rate (us-1), 0.1<=K<=6
% KG static Gauss Kubo-Toyabe, KTG(t)*exp(-t*L)  
%    A=kgAmp asymmetry, unlim
%    B=kgGau field (Gauss), longitudinal external field, 1e-3<=B<=1e5
%    D=kgDeG rate (us-1), 2nd moment of field/(2*pi*gamma_mu) 1e-3<=D<=1e3
%    L=kgDeLo Lorentzian rate (us-1), unlim
% KL static Lorentz Kubo-Toyabe,
%    A=klAmp asymmetry, unlim
%    B=klGau field (Gauss), longitudinal external field, 1e-3<=B<=1e5
%    D=klDeG rate (us-1), 2nd moment of field/(2*pi*gamma_mu) 1e-3<=D<=1e3
%    L=klDeLo Lorentzian rate (us-1), unlim
%
% Main Menus: 
% SAVE/QUIT 
%    SAVE MULAB.mat in the root directory (where MATLAB was
%    started) with present settings
%    SET LOCATION: ISIS is exclusively for the ISIS cabin PCs
%                  PSI is exclusively for the PSI llc cluster boxes
%                  home is for your own computer (linux or WIN)
%    (dealt with by mucd)
%    SET FILENAME PREFIX: (mucd) write the first part of your data
%    filenames, before the significant part of the run number, e.g.
%               MUSR000 for MUSR00023134.nxs
%               deltat_pta_gps_ for deltat_pta_gps_0234.bin (it can
%               cope with a few zeros)
%               gps for gps00234.bin for the above, renamed
%    LOG PATH: SELECTABLE  
%   (ROOTDIR is the path where you launched mulab from matlab)
%                   WIN home you are asked where to put logs each time
%                   you choose a new data path 
%                   WIN ISIS log path is fixed to ROOTDIR\log
%                   linux PSI logs go to
%                   /afs/psi.ch/user/x/xuser/mulab/live/
%              MIRROR 
%                   WIN home: a subdirectory \MuSR\ must exist, 
%                   data must be stored under further
%                   subdirectories (...\MuSR\sub\sub1\) and logs will
%                   be mirrored to corresponding (...\Mulab\sub\sub1)
%                   WIN ISIS: not applicable
%                   linux PSI: data in /afs/psi.ch/user/x/xuser/wherever/
%                   logs go automatically into 
%                   /afs/psi.ch/user/x/xuser/wherever/log/
%                   linux home: data in /home/.../facility/sub1/sub2
%                   logs in /home/user/mulab/facility/sub1/sub2
%    (dealt with by mucd)
%    QUIT ditto
% DATA FORMAT selects format/displays present format in red
% INSTRUMENT selects instrument/displays present in red
%     It is suggested that each instrument is analysed restarting
%     mulab from a dedicated directory (with its specific MULAB.mat)
% PLOTS 
%     DETECTORS to inspect their prompts
%     PARAMETERS vs. T, B (uses nominal T and B from TITLE), run number. See
%     above (PLOT in FIT PARAMETERS) for their selection
%     PARAMETERS vs. X, declare global MU_FIG and define
%          MU_FIG.X=[values ...];
%       in command window (respect uppercase!). As many values as
%       model.run-detector_version.fit files in the log directory
%     OVERLAY ASYMMETRY, to quickly compare different runs
% SETUP
%     LOAD GROUPS into .grp file (use descriptive names)
%     SAVE GROUPS from .grp file
%     DETERMINE t=0 fits prompt/pulsed beam features to obtain it
%     OFFSET to display/select first good bin (T0+OFFSET)
% TOTAL COUNTS display
% HELP memo and browser help desk
%
% MULAB produces three kinds of LOGs, with selectable VERSIONs: 
% One mat file for each fit (e.g damu.5342.3-4_1.fit) 
% One human readable ascii file per fit, (e.g damu.5342.3-4_1.log)
% One ascii data matrix with a line per each fit of a given model
% in the present directory, (e.g. damu.3-4_1.dat)
%
% Copyleft RDR Jan 2009
% Simplified GNU license: you can do whatever you like with this
% toolbox, on your PCs. If you want to recirculate a modified
% version, please let me know: roberto.derenzi at unipr.it subj: mulab


   global MU_MODEL MU_PATH MU_DATA MU_FIG MU_GEAR MU_ADD MU_VERSION
   
% General layout of this routine: divided in two panels, top one
% for actions and general parameters, bottom for fit parameters,
% plus a few toolbar menus. In the uicontrol style each object
% (edit, pushbutton, popupmenu, checkbox) has a CallBack function.
% 
% Graphic data is passed to CallBack functions by GUIDATA
%
% Mulab relies on a number of global structures, see HELP MU_GLOBAL
% See 
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.MulabChangelog
% for major changes


   gray=[0.8 0.8 0.8];
   blue=[0.1 0.2 0.8];
   azzurro=[0.9 0.95 1];
   pink=[1 0.9 0.9];
   white=[1 1 1];
%    First check if a window is out, in that case raise it 

if isempty(varargin)   % The default is when the figure is
                       % layed out: mufit_gui is called without args

    if ~isempty(findobj('Name',MU_FIG.MENUNAME)) % figure exists
                                                 % Save first a few
                                                 % things
        if ~isempty(guidata(MU_FIG.MENU))
            menutags=guidata(MU_FIG.MENU);
            if isfield(menutags,'PlotFieldRange')
                PlotFitRange=menutags.PlotFitRange;
            end
            if isfield(menutags,'PlotFitParameters')
                PlotFitParameters=menutags.PlotFitParameters; 
            end
            if isfield(menutags,'FFTRange')            
                FFTRange=menutags.FFTRange;
            end
            if isfield(menutags,'LineBroadening')
                LineBroadening=menutags.LineBroadening;
            end
        end
        close(MU_FIG.MENU); % a call without argin means re-lay-out
                            % the figure from scratch (e.g. new
                            % model) 
    end
    
elseif ~isempty(guidata(MU_FIG.MENU))   % A call to mufit_gui(1) is the method
                                        % to avoid re-layout afresh the figure, 
                                        % if guidata already exists
                                        % (the layout is set)
                                        % just bring the figure to focus.
                                        % Handle is stored in MU_FIG.MENU
    figure(MU_FIG.MENU) 
    return 
end
figure(MU_FIG.MENU)
set(MU_FIG.MENU,'Name',MU_FIG.MENUNAME,'Visible','off',...
                'MenuBar','None');

%    If not, draw one
%    starting from the layout

existsmodel=isfield(MU_MODEL,'NAME');

if existsmodel
   p=0; % parameter count
   
   component=MU_MODEL.COMPONENTNUMBER;
   panelrow=ceil(component/2); % divide into 2 columns
   panelcol=2;
   %   if component==1, panelcol=1; end
   
   par=[];
   rows=[];
   for k=1:component
       if k~=floor(k/2)*2, % odd
           pk=[];
       end
       park=MU_MODEL.COMPONENT(k).PARAMETERNUMBER;
       pk=[pk park]; % pair of components
       par=[par park];
       if k==floor(k/2)*2, % even
           rows=[rows max(pk)]; % max number of par of the pair 
       end
   end
   if component~=round(component/2)*2 % even components
       rows=[rows park]; % add last component
   end
else % no model yet should never happen, normally
    par=[];
    panelrow=1; %give window a minimum size
    panelcol=2;
    component=0;
    rows=[];
end
   dX=5;
   dY=5;
   Xtwidth=60; % standard text width
   Xbwidth=15; % width of FFT button
   Xn=20;
   Ytwidth=20;

   totX=Xn+3*Xtwidth+4*dX+Xbwidth;
   totY=Ytwidth+dY;
   Xmin=100;
   Ymin=600;
   Xwidth=panelcol*totX+(panelcol-1)*3*dX+10*dX; %frame is 2dX per
                                                 %side
   Ywidthpar=6*dY*panelrow+(sum(rows)+1)*totY; 
   % accomodate fitmenu,
   Ywidthmenu=7*totY+9*dY; 
   Ywidthtot=Ywidthpar+Ywidthmenu+3*dY;   
   PPx=dX/Xwidth;
   PPy=dY/Ywidthtot;
   PPWx=1-2*PPx;
   PPWpy=(Ywidthpar)/Ywidthtot-PPy;
   PPWmy=(Ywidthmenu+2*dY)/Ywidthtot-2*PPy;
   PPpy=1.25*PPy;
   PPmy=PPWpy+2.5*PPy;
  
   %  Create and hide the GUI as it is being constructed.
   figure(MU_FIG.MENU)
   set(MU_FIG.MENU,'Visible','off',...
                   'Position',[Xmin,Ymin,Xwidth,Ywidthtot])
   
   % Place the fitmenu panel at the top
   hm = uipanel('Title','Fit menu',...
             'Position',[PPx PPmy PPWx PPWmy]);
   % made of alpha, bin, range, 
   X=dX;
   Y=Ywidthmenu-2*dY-totY;
   Nmenumenu=27; % tags in the Fit menu
   Nmenucontrols=Nmenumenu+2*sum(par); % total tags: 
                               % those in teh Fit menu plus 2 times the
                               % number of parameters (value, flag)
   red=[0.8 .2 .2];
   white=[1 1 1];
   
   if isempty(guidata(MU_FIG.MENU))
       menutags.tag=cell(1,Nmenucontrols); % Tags for the menu uicontrols. 
                                   % Starts empty, filled as the
                                   % figure is layed out, will be
                                   % stored with guidata(MU_FIG.MENU,menutags)
                                   % and retrieved with menutags=guidata(gcf);
   else
       menutags=guidata(gcf);
   end
   
% tagmenu=[ 'SAVEMULAB' 'LOCATION' 'PREFIX' 'QUIT'};

   hsave = uimenu(MU_FIG.MENU,'Label','Save/Quit');
   h1=uimenu(hsave,'Label','Save MuLab',...
              'Tag','SAVEMULAB',...
              'Callback',@Save_CallBack);
   %h2=uimenu(hsave,'Label','Save model (bare)',...
   %           'Tag','SAVEMODEL',...
   %           'Callback',@Save_CallBack);
   %h3=uimenu(hsave,'Label','Rehash',...
   %           'Tag','REHASH',...
   %           'Callback',@Save_CallBack);
   if isfield(MU_GEAR,'LOCATION')
       string=(['Set Location: [' MU_GEAR.LOCATION ']']);
   else
       string=('Set Location: []');
   end
   
   h2=uimenu(hsave,'Label',string,...
              'Tag','LOCATION',...
              'Callback',@Save_CallBack); % is written in MU_GEAR.LOCATION
   if isfield(MU_GEAR,'FILENAME_PREFIX')
       string=(['Set filename prefix: [' MU_GEAR.FILENAME_PREFIX ']']);
   else
       string=('Set filename prefix: []');
   end

   h3=uimenu(hsave,'Label',string,...
              'Tag','PREFIX',...
              'Callback',@Save_CallBack); % is written in MU_GEAR.FILENAME_PREFIX
   if ~isfield(MU_GEAR,'AUTOLOGPATH')
       MU_GEAR.AUTOLOGPATH='Selectable';
   end
   string=(['Log path policy: [' MU_GEAR.AUTOLOGPATH ']']);
   h3bis=uimenu(hsave,'Label',string,...
              'Tag','AUTOLOGPATH',...
              'Callback',@Save_CallBack); % is written in MU_GEAR.FILENAME_PREFIX
   h4=uimenu(hsave,'Label','Quit',...
              'Tag','QUIT',...
              'Callback',@Save_CallBack);
% % --------------------- from here   
% % tagmenu=[ 'PSIASCII' 'PSIBIN' 'ISISMCS' 'ISISNXS' ...
% %          'GPS' 'LTF' 'DOLLY' 'GPD' 'MUS64' 'MUS' 'EMU'};
%    hrig = uimenu(MU_FIG.MENU,'Label','Data Format');
%    h5=uimenu(hrig,'Label','PSI ascii',...
%           'Tag','PSIASCII',...
%           'Callback',@Rig_CallBack);
%    h6=uimenu(hrig,'Label','PSI bin',...
%           'Tag','PSIBIN',...
%           'Callback',@Rig_CallBack);
%    h7=uimenu(hrig,'Label','ISIS MCS',...
%           'Tag','ISISMCS',...
%           'Callback',@Rig_CallBack);
%    h8=uimenu(hrig,'Label','ISIS nxs',...
%           'Tag','ISISNXS',...
%           'Callback',@Rig_CallBack);
%    hinstrPSI = uimenu(MU_FIG.MENU,'Label','Instruments PSI',...
%                       'Tag','PSImenu','Visible','off');
%    hinstrISIS = uimenu(MU_FIG.MENU,'Label','Instruments ISIS',...
%                        'Tag','ISISmenu','Visible','off');
%    if findstr(MU_GEAR.FACILITY,'PSI'), 
%        set(hinstrPSI,'Visible','on'), 
%    elseif findstr(MU_GEAR.FACILITY,'ISIS')
%        set(hinstrISIS,'Visible','on')
%    end
%    if findstr(MU_GEAR.DATA_TYPE,'ASCII')
%        set(h5,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.DATA_TYPE,'BIN')
%        set(h6,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.DATA_TYPE,'MCS')
%        set(h7,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.DATA_TYPE,'NEXUS')
%        set(h8,'Foregroundcolor',red)
%    end
%    h9=uimenu(hinstrPSI,'Label','gps',...
%           'Tag','GPS',...
%           'Callback',@Rig_CallBack);
%    h10=uimenu(hinstrPSI,'Label','ltf',...
%           'Tag','LTF',...
%           'Callback',@Rig_CallBack);
%    h11=uimenu(hinstrPSI,'Label','dolly',...
%           'Tag','DOLLY',...
%           'Callback',@Rig_CallBack);
%    h11b=uimenu(hinstrPSI,'Label','gpd',...
%           'Tag','GPD',...
%           'Callback',@Rig_CallBack);
%    h12=uimenu(hinstrISIS,'Label','mus64',...
%           'Tag','MUS64',...
%           'Callback',@Rig_CallBack);
%    h13=uimenu(hinstrISIS,'Label','mus32',...
%           'Tag','MUS',...
%           'Callback',@Rig_CallBack);
%    h14=uimenu(hinstrISIS,'Label','emu',...
%           'Tag','EMU',...
%           'Callback',@Rig_CallBack);
%    if findstr(MU_GEAR.INSTRUMENT,'GPS')
%        set(h9,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.INSTRUMENT,'LTF')
%        set(h10,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.INSTRUMENT,'DOL')
%        set(h11,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.INSTRUMENT,'MUS64')
%        set(h12,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.INSTRUMENT,'MUS')
%        set(h13,'Foregroundcolor',red)
%    elseif findstr(MU_GEAR.INSTRUMENT,'EMU')
%        set(h14,'Foregroundcolor',red)
%    end
% %----- to here: delete

%   hplots = uimenu(MU_FIG.MENU,'Label','RotframeFit');

   hplots = uimenu(MU_FIG.MENU,'Label','Plots');
 
   h15=uimenu(hplots,'Label','Plot Detectors',...
              'Tag','PlotHisto',...
              'Callback',@Plots_CallBack);
   h16=uimenu(hplots,'Label','Plot Parameters vs. T',...
              'Tag','PlotT',...
              'Callback',@Plots_CallBack);

   h17=uimenu(hplots,'Label','Plot Parameters vs. B',...
              'Tag','PlotB',...
              'Callback',@Plots_CallBack);

   h18=uimenu(hplots,'Label','Plot Parameters vs. x',...
              'Tag','Plotx',...
               'Callback',@Plots_CallBack);

   h18_bis=uimenu(hplots,'Label','Plot Parameters vs. run number',...
              'Tag','PlotRun',...
               'Callback',@Plots_CallBack);

   h18_ter=uimenu(hplots,'Label','Overlay asymmetries',...
              'Tag','PlotOver',...
               'Callback',@Plots_CallBack);

   hsetup = uimenu(MU_FIG.MENU,'Label','Setup');
 
   h19=uimenu(hsetup,'Label','Load groups',...
              'Tag','LoadGroups',...
              'Callback',@Setup_CallBack);
   h20=uimenu(hsetup,'Label','Save groups',...
              'Tag','SaveGroups',...
              'Callback',@Setup_CallBack);
   h21=uimenu(hsetup,'Label','Determine t=0',...
              'Tag','SetTime',...
              'Callback',@Setup_CallBack);
   h22=uimenu(hsetup,'Label',['Offset (' num2str(MU_GEAR.OFFSET) ')'],...
              'Tag','Offsets',...
              'Callback',@Setup_CallBack);
   nt0=[];
   dt=[];
   
   if strcmp(MU_GEAR.FACILITY,'ISIS')
       if isfield(MU_GEAR,'NT0')
           nt0=int2str(MU_GEAR.NT0(1));
           dt=num2str(MU_GEAR.DT(1),2);
       end
   else
       if isfield(MU_GEAR,'NT0')
           nt0=int2str(MU_GEAR.NT0);
           dt=num2str(MU_GEAR.DT,'%0.2g ');
       end
   end
   h23=uimenu(hsetup,'Label',['t0=(' nt0 ')'],...
              'Tag','Displayt0');
   h24=uimenu(hsetup,'Label',['dt=(' dt ')'],...
              'Tag','Displaydt');
   h25=uimenu(hsetup,'Label','Set t0 manually',...
              'Tag','Sett0',...
              'Callback',@Setup_CallBack);
   h26=uimenu(hsetup,'Label','Set dt manually',...
              'Tag','Setdt',...
              'Callback',@Setup_CallBack);
   switch MU_GEAR.INSTRUMENT
     case {'GPS','LTF'}
       if  ~isfield(MU_GEAR,'MODE')
              MU_GEAR.MODE='NO MORE';
       end
       h260=uimenu(hsetup,'Label',['Toggle mode, now: ' MU_GEAR.MODE],...
                   'Tag','Mode',...
                   'Callback',@Setup_CallBack);
       if  ~isfield(MU_GEAR,'BCKG')
              MU_GEAR.BCKG='PREPROMPT';
       end
       h260=uimenu(hsetup,'Label',['Toggle mode, now: ' MU_GEAR.BCKG],...
                   'Tag','Bckg',...
                   'Callback',@Setup_CallBack);
           
   end
   
   htotals = uimenu(MU_FIG.MENU,'Label','This run',...
                    'Tag','Total Counts');
    
   if isfield(MU_DATA,'NRUN')
       ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
       string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
   else
       string='Total counts';
   end
   h27=uimenu(htotals,'Label',string,...
              'Tag','Total');
   
   if isfield(MU_DATA,'NRUN')
       if isfield(MU_MODEL,'NAME')
           group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
           ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
           string=['Group total counts ' num2str(ntot/1e6,3) ' Mev'];
       else
           string='Group total counts';
       end
   else
       string='Group total counts';
   end
   h28=uimenu(htotals,'Label',string,...
              'Tag','GroupTotal');

   if isfield(MU_DATA,'RESNS')
       string=['ns/bin ' num2str(MU_DATA.RESNS)];
   else
       string='ns/bin';
   end
   h28b=uimenu(htotals,'Label',string,...
               'Tag','NsBin');
   
   if isfield(MU_DATA,'START_DATE')
       stringstart=['Started ' MU_DATA.START_DATE ...  
               ',' MU_DATA.START_TIME];
       stringstop=['Saved ' MU_DATA.STOP_DATE ...  
               ',' MU_DATA.STOP_TIME];
       comment=deblank(MU_DATA.COMMENTS);
   else
       stringstart='';
       stringstop='';
       comment='';
   end
   stringfacility=MU_GEAR.FACILITY;  % Tag Facility
   stringdatatype=MU_GEAR.DATA_TYPE; % Tag DataType
   stringinstrument=MU_GEAR.INSTRUMENT; % Tag Instrument

   h29=uimenu(htotals,'Label',stringstart,'Tag','StartDate');
   h30=uimenu(htotals,'Label',stringstop,'Tag','StopDate');
   h31=uimenu(htotals,'Label',comment,'Tag','Comment');
   h32=uimenu(htotals,'Label',stringfacility,'Tag','Facility');
   h33=uimenu(htotals,'Label',stringdatatype,'Tag','DataType');
   h34=uimenu(htotals,'Label',stringinstrument,'Tag','Instrument');
   
   hhelp=uimenu(MU_FIG.MENU,'Label','Help');
   hhelp1=uimenu(hhelp,'Label','hint: type help mulab');
   hhelp2=uimenu(hhelp,'Label','hint: type help mufit_gui');
   hhelp3=uimenu(hhelp,'Label','Browser: helpdesk',...
                 'Tag','Browser','Callback',@Help_CallBack);
   hhelp4=uimenu(hhelp,'Label','Browser: Path policy',...
                 'Tag','Pathpolicy','Callback',@Help_CallBack);
   hhelp5=uimenu(hhelp,'Label','Browser: set t=0',...
                 'Tag','Tzero','Callback',@Help_CallBack);
   hhelp6=uimenu(hhelp,'Label','Browser: Fit model',...
                 'Tag','Model','Callback',@Help_CallBack);
   hhelp7=uimenu(hhelp,'Label','List available components',...
              'Tag','ListComponents','Callback',@Help_CallBack);

   % logo:  -------------------------------------------------------------
   %  trick: axes (uicontrol text do not understand TeX)
   hlogo = axes('Parent',hm,...
                'Box','on',...
                'Unit','pixel',...
                'xticklabel',[],'yticklabel',[],...
                'Position',...
                [X,Y-totY-dY,Xtwidth+2*dX,2*totY]);
   text(0.07,0.6,' {\mu}lab ',...
                     'Fontname','Arial',...
                     'Fontsize',20,...
                     'color',blue,...
                     'Fontweight','bold',...
        'Backgroundcolor',azzurro)
   string=['Ver. ' MU_VERSION];
   bks='              ';
   string=[string bks];
   string=string(1:15);
   text(0.07,0.1,string,...
                     'Fontname','Arial',...
                     'Fontsize',9,...
                     'color',blue,...
                     'Fontweight','normal',...
                     'Backgroundcolor',azzurro)

   % HERE STARTS THE GUI LAYOUT 
   %   typical GUI implementation:
   %   here the default string value (read from MU_MODEL.GROUPING.FORWARD 
   %   by means of musgroup(1,0)) is stored in the Edit uicontrol
   %   with a unique tag. When the uicontrol is edited by the user, the 
   %   function Menu_CallBack(hFgroup) is automatically called. 
   %   The function is defined below and it can read the data from
   %   the varagrin(1), contaings the handle hFgroup. 
   %   It can also identify one uicontrol among
   %   many, since the whole set of handles of the figure are
   %   stored and may be retireved with figure_handles=guihandles;
   %   In Menu_CallBack
   %       menutags=guidata(gcf);
   %        ..
   %       getfield(figure_handles,menutags(k)) 
   %       figure_handles.Fgroup==cell2mat(varargin(1))
   %   will be true for the k-th uicontrol (the first in the
   %   present case) and menutags(k) will reveal its unique tag (a
   %   switch can then distribute parameters in used space)

   % banner
   % prints Mulab version, 
   % dataset loaded, if any and 
   % model loaded, if any
   
   X=X+1*Xtwidth+dX+2*dX;
   if isfield(MU_DATA,'NRUN')
       if isempty(MU_ADD)
           runs=int2str(MU_DATA.NRUN);
       else
           arun=num2str(MU_ADD(1));
           for k=2:length(MU_ADD)
               arun=[arun '+' num2str(MU_ADD(k))];
           end
           runs=[int2str(MU_DATA.NRUN) '+' arun];
       end
       string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
              deblank(MU_DATA.ORIENTATION) ' ' ...
              ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
              ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
   else 
       string='No data';
   end
   tag='RunTitle';
   htxtdata = uicontrol('Parent',hm,...
                        'Style','text',...
                        'String',string,...
                        'Tag',tag,...
                        'Horizontalalignment','Left',...
                        'BackGroundColor',blue,...
                        'FontWeight','bold',...
                        'Foregroundcolor',azzurro,...
                        'Position',...
                        [X,Y,5*Xtwidth,Ytwidth]);

   if isfield(MU_PATH,'DATA')
       string=MU_PATH.DATA;
   else
       string='';
   end
       tag='DataDir';
       htxtdatadir=uicontrol('Parent',hm,...
                             'Style','text',...
                             'Fontsize',8,...
                             'Tag',tag,...
                             'String',string,...
                             'Horizontalalignment','Left',...
                             'Position',...
                             [X,Y-0.8*Ytwidth,4*Xtwidth,Ytwidth/2]);  

   X=X+5.1*Xtwidth+dX;
   if isfield(MU_MODEL,'NAME')
       string=MU_MODEL.NAME;
       if isfield(MU_MODEL,'NRUN')
           string=[string '.' num2str(MU_MODEL.NRUN)];
       end
   else 
       string='No model';
   end
   tag='GuessModel';
   htxtmodel = uicontrol('Parent',hm,...
                         'Style','text',...
                         'String',string,...
                         'Tag',tag,...
                         'Horizontalalignment','Left',...
                         'BackgroundColor',azzurro,...
                         'ForegroundColor',blue,...
                         'FontWeight','demi',...
                         'Position',...
                         [X,Y,2*Xtwidth,Ytwidth]);
   
   
   % 1st row -------------------------------------------------------

   X=2*dX+1*Xtwidth+2*dX;
   Y=Y-dY-1.5*totY;
   htxtFgroup = uicontrol('Parent',hm,...
                      'Style','text',...
                      'String','Forward group',...
                      'Horizontalalignment','Right',...
                      'Position',...
                      [X,Y,1.7*Xtwidth,Ytwidth]);
   tag='Fgroup';
   menutags.tag(1)={tag};
   X=X+1.7*Xtwidth+dX;
   if existsmodel
       string=musgroup(1,0);
   else 
       string=' ';
   end
   hFgroup = uicontrol('Parent',hm,...
                       'Style','Edit',...
                       'String',string,...
                       'Tag',tag,...
                       'Callback',@Menu_CallBack,...
                       'Horizontalalignment','Left',...
                       'Position',...
                      [X,Y,1.3*Xtwidth,Ytwidth],...
                         'Backgroundcolor','white');
   X=X+1.2*Xtwidth+dX;
   htxtalpha = uicontrol('Parent',hm,...
                      'Style','text',...
                      'String','Alpha',...
                      'Horizontalalignment','Right',...
                      'Position',...
                      [X,Y,0.7*Xtwidth,Ytwidth]);
   tag='Alpha';
   menutags.tag(2)={tag};
   X=X+0.7*Xtwidth+dX;
   if existsmodel
       string=num2str(MU_MODEL.ALPHA);
   else 
       string=' ';
   end
   halpha = uicontrol('Parent',hm,...
                      'Style','Edit',...
                      'String',string,...
                      'Tag',tag,...
                      'Callback',@Menu_CallBack,...
                      'Horizontalalignment','Left',...
                      'Position',...
                      [X,Y,0.8*Xtwidth,Ytwidth],...
                         'Backgroundcolor','white');
   X=X+1.1*Xtwidth+dX;
   htxtrange = uicontrol('Parent',hm,...
                         'Style','text',...
                         'String','Fit Range',...
                         'Horizontalalignment','Right',...
                         'Position',...
                         [X,Y,1.0*Xtwidth,Ytwidth]);

   tag='Range';
   menutags.tag(3)={tag};
   X=X+1.1*Xtwidth+dX;
   if existsmodel
       string=num2str(MU_MODEL.RANGE);
   else 
       string=' ';
   end   
   hrange = uicontrol('Parent',hm,...
                      'Style','Edit',...
                      'String',string,...
                      'Tag',tag,...
                      'Callback',@Menu_CallBack,...
                      'Horizontalalignment','Left',...
                      'Position',...
                      [X,Y,Xtwidth*1,Ytwidth],...
                         'Backgroundcolor','white');
   % 2 row -----------------------------------------------------
   % Fgroup, Bgroup, denom, batch 
   X=2*dX+1*Xtwidth+2*dX;
   Y=Y-dY-totY;
   htxtBgroup = uicontrol('Parent',hm,...
                          'Style','text',...
                          'String','Backward group',...
                          'Horizontalalignment','Right',...
                          'Position',...
                          [X,Y,1.7*Xtwidth,Ytwidth]);
   tag='Bgroup';
   menutags.tag(4)={tag};
   X=X+1.7*Xtwidth+dX;
   if existsmodel
       string=musgroup(2,0);
   else 
       string=' ';
   end   
   hBgroup = uicontrol('Parent',hm,...
                       'Style','Edit',...
                       'String',string,...
                       'Tag',tag,...
                       'Callback',@Menu_CallBack,...
                       'Horizontalalignment','Left',...
                       'Position',...
                       [X,Y,1.3*Xtwidth,Ytwidth],...
                       'Backgroundcolor','white');
   X=X+1.2*Xtwidth+dX;
   htxtbin = uicontrol('Parent',hm,...
                      'Style','text',...
                      'String','Bin',...
                      'Horizontalalignment','Right',...
                      'Position',...
                      [X,Y,0.7*Xtwidth,Ytwidth]);
   tag='Bin';
   menutags.tag(5)={tag};
   X=X+0.7*Xtwidth+dX;
   if existsmodel
       string=num2str(MU_MODEL.BIN);
   else 
       string=' ';
   end
   hbin = uicontrol('Parent',hm,...
                    'Style','Edit',...
                    'String',string,...
                    'Tag',tag,...
                    'Callback',@Menu_CallBack,...
                    'Horizontalalignment','Left',...
                    'Position',...
                    [X,Y,0.8*Xtwidth,Ytwidth],...
                         'Backgroundcolor','white');
   X=X+1.1*Xtwidth+dX;
   hpanelplot = uipanel('Parent',hm,'Title','','Units','pixels',...
          'Position',[X-0.27*Xtwidth Y-3.2*Ytwidth 2.55*Xtwidth 4.4*Ytwidth]);
   htxtnextrun = uicontrol('Parent',hm,...
                           'Style','text',...
                           'String','Next Run',...
                           'Horizontalalignment','Right',...
                           'Position',...
                           [X,Y,Xtwidth,Ytwidth]);
   tag='NextRun';
   menutags.tag(6)={tag};
   X=X+1.1*Xtwidth+dX;
   color='white';
   if isfield(MU_DATA,'NRUN')       
       nextrun=num2str(MU_DATA.NRUN+1);
         if ~mucanload(nextrun)
            nextrun=[];
%            msgbox(['Next run ' num2str(MU_DATA.NRUN+1) ' does not exist'],...
%                   'Next run','non-modal') %otherwise steals focus from
%                                           %MU_FIG.MENU
            color=pink;
       end
   else
       nextrun=[];
   end
   hnextrun = uicontrol('Parent',hm,...
                        'Style','Edit',...
                        'String',nextrun,...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Horizontalalignment','Left',...
                        'Position',...
                        [X,Y,Xtwidth,Ytwidth],...
                        'Backgroundcolor',color);
   % 3rd row,  buttons ---------------
   
   tag='Fit';
   menutags.tag(7)={tag};
   X=1.2*dX;
   Y=Y-dY-1*totY;
   hpanelplot = uipanel('Parent',hm,'Title','','Units','pixels',...
                        'Position',[X-3*dX/4 Y-3.8*Ytwidth ...
                       1.14*Xtwidth+1.5*dX 6.8*Ytwidth]);
   hfit = uicontrol('Parent',hm,...
                    'Style','pushbutton','Backgroundcolor',gray,...
                    'String','Do Fit',...
                    'Tag',tag,...
                    'Callback',@Menu_CallBack,...
                    'Position',...
                    [X,Y+0.8*Ytwidth,Xtwidth+2*dX,2*Ytwidth]);    
   % tag='Auto';
   % menutags.tag(8)={tag};
   % X=X+1.1*Xtwidth+dX+2*dX;
   % htogglebatch = uicontrol('Parent',hm,...
   %                          'Style','popupmenu',...
   %                          'String',{'Batch','Interactive'},...
   %                          'Tag',tag,...
   %                          'Callback',@Menu_CallBack,...
   %                          'Value',1,...
   %                          'Position',...
   %                          [X,Y,1.2*Xtwidth,Ytwidth]);   
   % htxt1 = uicontrol('Parent',hm,...
   %                  'Style','text',...
   %                  'Fontsize',8,...
   %                  'String','Minuit',...
   %                  'Horizontalalignment','Center',...
   %                  'Position',...
   %                  [X,Y-Ytwidth/2,1.2*Xtwidth,Ytwidth/2]);
   % htxt2 = uicontrol('Parent',hm,...
   %                  'Style','text',...
   %                  'Fontsize',8,...
   %                  'String','Mode',...
   %                  'Horizontalalignment','Center',...
   %                  'Position',...
   %                  [X,Y-Ytwidth,1.2*Xtwidth,Ytwidth/2]);
   % tag='Denom';
   % menutags.tag(9)={tag};
   % X=X+1.2*Xtwidth+dX;
   % htoggledenom = uicontrol('Parent',hm,...
   %                          'Style','popupmenu',...
   %                          'String',{'Fit','Data'},...
   %                          'Value',1,...
   %                          'Tag',tag,...
   %                          'Callback',@Menu_CallBack,...
   %                          'Position',...
   %                          [X,Y,Xtwidth,Ytwidth]);

   % htxt3 = uicontrol('Parent',hm,...
   %                  'Style','text',...
   %                  'Fontsize',8,...
   %                  'String','Asymmetry',...
   %                  'Horizontalalignment','Center',...
   %                  'Position',...
   %                  [X,Y-Ytwidth/2,Xtwidth,Ytwidth/2]);
   % htxt4 = uicontrol('Parent',hm,...
   %                  'Style','text',...
   %                  'Fontsize',8,...
   %                  'String','denomin.',...
   %                  'Horizontalalignment','Center',...
   %                  'Position',...
   %                  [X,Y-Ytwidth,Xtwidth,Ytwidth/2]);
   tag='LoadModel';
   menutags.tag(10)={tag};
   X=X+1.1*Xtwidth+dX;
   hloadmodel = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','LdModel',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y,Xtwidth,Ytwidth]);    
   tag='EdModel';
   menutags.tag(11)={tag};
   hedmodel = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','EdModel',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y-Ytwidth-2*dY,Xtwidth,Ytwidth]);    
 
   tag='ModelName';   
   menutags.tag(12)={tag};
   X=X+Xtwidth+dX;
   hmodelname = uicontrol('Parent',hm,...
                          'Style','Edit',...
                          'String',[],...
                          'Tag',tag,...
                          'Callback',@Menu_CallBack,...
                          'Horizontalalignment','Left',...
                          'Backgroundcolor','white',...
                          'Position',...
                          [X,Y,0.9*Xtwidth,Ytwidth]);    
   tag='Path';   
   menutags.tag(13)={tag};
   hpath = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','Path',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y-Ytwidth-2*dY,0.9*Xtwidth,Ytwidth]);    
 
   tag='AddPrev';
   menutags.tag(14)={tag};
   X=X+1.1*Xtwidth+dX;
   haddrun = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','<+',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y-Ytwidth-2*dY,0.5*Xtwidth,Ytwidth]);       

   tag='LoadPrev';
   menutags.tag(15)={tag};
   hloadrun = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','< ',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y,0.5*Xtwidth,Ytwidth]);    

   tag='AddGui';
   X=X+0.5*Xtwidth+dX;
   menutags.tag(16)={tag};
   haddgui = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','Add',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y-Ytwidth-2*dY,1.1*Xtwidth,Ytwidth]); ...
             

   tag='LoadGui';
   menutags.tag(17)={tag};
   hloadgui = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','Load',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y,1.1*Xtwidth,Ytwidth]);    

   
   tag='AddNext';
   menutags.tag(18)={tag};
   X=X+1.1*Xtwidth+dX;
   haddrun = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','+>',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y-Ytwidth-2*dY,0.5*Xtwidth,Ytwidth]);    
             
   tag='LoadNext';
   menutags.tag(19)={tag};
   hloadrun = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String',' >',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y,0.5*Xtwidth,Ytwidth]);    


   % Fourth line
   % muupdatemodel(button), plot(button) plotrange(edit)
   % guess/result(popup) fft(button) LB(edit) range(edit)  
   % 

   X=dX;
   Y1=Y-dY-0.1*totY;
   hlogversiontxt = uicontrol('Parent',hm,...
                              'Style','text',...
                              'Fontsize',8,...
                              'String','Log version',...
                              'Horizontalalignment','Right',...
                              'Position',...
                              [X,Y1+0*totY,Xtwidth,Ytwidth/2]);    
   tag='LogVersion';
   menutags.tag(20)={tag};
   Y1=Y1-1*totY;
   if existsmodel
       if ~isfield(MU_MODEL.FLAG,'LOGVERSION')
           MU_MODEL.FLAG.LOGVERSION='1';
              string='1';
       else
           if isnumeric(MU_MODEL.FLAG.LOGVERSION)
               MU_MODEL.FLAG.LOGVERSION= ...
                   num2str(MU_MODEL.FLAG.LOGVERSION);
           end % correct an old error
           string=MU_MODEL.FLAG.LOGVERSION;
       end
   else 
       string=' ';
   end
      
   hlogversion = uicontrol('Parent',hm,...
                           'Style','edit',...
                           'String',string,...
                           'Tag',tag,...
                           'Horizontalalignment','Left',...
                           'Backgroundcolor','white',...
                           'Callback',@Menu_CallBack,...
                           'Position',...
                           [X,Y1+0*totY,Xtwidth+2*dX,Ytwidth]);    
   tag='Update';
   menutags.tag(21)={tag};
   Y1=Y1-1*totY;
   hupdate = uicontrol('Parent',hm,...
                       'Style','pushbutton','Backgroundcolor',gray,...
                       'String','Update',...
                       'Tag',tag,...
                       'Callback',@Menu_CallBack,...
                       'Position',...
                       [X,Y1-0.4*totY,Xtwidth+2*dX,Ytwidth]);    

   tag='PlotFit';
   menutags.tag(22)={tag};
   X=X+1.1*Xtwidth+dX+2*dX;
   Y=Y-3*dY-2*totY;
   hpanelplot = uipanel('Parent',hm,'Title','','Units','pixels',...
             'Position',[X-dX Y-0.6*Ytwidth 3.6*Xtwidth 1.95*Ytwidth]);
   hplotfit = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','PlotFit',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y,Xtwidth,Ytwidth]);   
   tag='PlotFitRange';
   menutags.tag(23)={tag};
   if exist('PlotFitRange')==1
       menutags.PlotFitRange=PlotFitRange;
   end
   if ~isfield(menutags,'PlotFitRange')
       menutags.PlotFitRange=[]; % starting default 
   end
   X=X+Xtwidth+dX;
   hplotfitrange = uicontrol('Parent',hm,...
                             'Style','Edit',...
                             'String',menutags.PlotFitRange,...
                             'Tag',tag,... 
                             'Horizontalalignment','Left',...
                             'Backgroundcolor','white',...
                             'Callback',@Menu_CallBack,...
                             'Position',...
                             [X,Y,1.2*Xtwidth,Ytwidth]);
   
   htxt5 = uicontrol('Parent',hm,...
                     'Style','text',...
                     'Fontsize',8,...
                     'String','Plot Range',...
                     'Horizontalalignment','Center',...
                     'Position',...
                     [X,Y-Ytwidth/2,1.2*Xtwidth,Ytwidth/2]);
   tag='PlotFitParameters';
   menutags.tag(24)={tag};
   if exist('PlotFitParameters')==1
       menutags.PlotFitParameters=PlotFitParameters;
   end
   if ~isfield(menutags,'PlotFitParameters')
       menutags.PlotFitParameters=1; % starting default
   end
   X=X+1.3*Xtwidth+dX;
   hplotfitpars = uicontrol('Parent',hm,...
                            'Style','popupmenu',...
                            'String',{'Guess','Results'},...
                            'Value',menutags.PlotFitParameters,...
                            'Tag',tag,...
                            'Callback',@Menu_CallBack,...
                            'Position',...
                            [X,Y,Xtwidth,Ytwidth]);    
   htxt6 = uicontrol('Parent',hm,...
                     'Style','text',...
                     'Fontsize',8,...
                     'String','Fit pars',...
                     'Horizontalalignment','Center',...
                     'Position',...
                     [X,Y-Ytwidth/2,Xtwidth,Ytwidth/2]);
   tag='FftResidues';
   menutags.tag(25)={tag};
   X=X+1.3*Xtwidth+dX;
   hpanelplot = uipanel('Parent',hm,'Title','','Units','pixels',...
             'Position',[X-2.8*dX Y-0.6*Ytwidth 3.6*Xtwidth 1.95*Ytwidth]);
   hfftres = uicontrol('Parent',hm,...
                        'Style','pushbutton','Backgroundcolor',gray,...
                        'String','FFT',...
                        'Tag',tag,...
                        'Callback',@Menu_CallBack,...
                        'Position',...
                        [X,Y,0.6*Xtwidth,Ytwidth]);
 
   htxt7 = uicontrol('Parent',hm,...
                    'Style','text',...
                    'Fontsize',8,...
                    'String','Residues',...
                    'Horizontalalignment','Center',...
                    'Position',...
                    [X-0.1*Xtwidth,Y-Ytwidth/2,0.9*Xtwidth,Ytwidth/2]);
   tag='FFTRange';   
   menutags.tag(26)={tag};
   if exist('FFTRange')==1
       menutags.FFTRange=FFTRange; 
       clear FFTRange
   end
   if ~isfield(menutags,'FFTRange')
       menutags.FFTRange='0 50'; % starting default 
   end
   X=X+0.7*Xtwidth+dX;
   hfftrange = uicontrol('Parent',hm,...
                         'Style','Edit',...
                         'String',menutags.FFTRange,...
                         'Tag',tag,...
                         'Callback',@Menu_CallBack,...
                         'Horizontalalignment','Left',...
                         'Backgroundcolor','white',...
                         'Position',...
                         [X,Y,1.2*Xtwidth,Ytwidth]); 
   htxt4 = uicontrol('Parent',hm,...
                     'Style','text',...
                     'Fontsize',8,...
                     'String','Range (MHz)',...
                     'Horizontalalignment','Center',...
                     'Position',...
                     [X,Y-Ytwidth/2,1.2*Xtwidth,Ytwidth/2]);
   tag='LineBroadening';   
   menutags.tag(27)={tag};
   if exist('LineBroadening')==1
       menutags.LineBroadening=LineBroadening; 
       % clear LineBroadening
   end
   if ~isfield(menutags,'LineBroadening')
       menutags.LineBroadening='1'; % starting default 
   end
   X=X+1.3*Xtwidth+dX;
   hlb = uicontrol('Parent',hm,...
                   'Style','Edit',...
                   'String',menutags.LineBroadening,...
                   'Tag',tag,... 
                   'Horizontalalignment','Left',...
                   'Backgroundcolor','white',...
                   'Callback',@Menu_CallBack,...
                   'Position',...
                   [X,Y,1.1*Xtwidth,Ytwidth]);    
 
   htxt4 = uicontrol('Parent',hm,...
                    'Style','text',...
                    'Fontsize',8,...
                    'String','LB (us-1)',...
                    'Horizontalalignment','Center',...
                    'Position',...
                    [X,Y-Ytwidth/2,Xtwidth,Ytwidth/2]);

   
 % fit parameters
 hp = uipanel('Title','Fit Parameters',...
             'Position',[PPx PPpy PPWx PPWpy]);

   Xr=dX;  
   Y=Ywidthpar-23-Ytwidth;% % distance from bottom of Fit
                                  % Parameter panel
   m=0; %component
   rows=[0 rows]; % previous rows
   ffton=[];
   for j=1:panelrow
       Y=Y-rows(j)*(totY)-(j>=2)*(totY+2*dY); % bottom of hps
                                           % (component) panels 
       for k=1:panelcol % 1 or 2
           X=Xr+(k-1)*(totX+6*dX);
           if ~(j-1) % header

               htext1=uicontrol('Parent',hp,...
                                'Style','text',...
                                'String','Value',...
                                'Position',...
                                [X+Xn+0.9*Xtwidth-dX...
                                 *(k-2),Y,...
                                 Xtwidth,Ytwidth]);
               htext2=uicontrol('Parent',hp,...
                                'Style','text',...
                                'String',' ~!=+ ',...
                                'Position',...
                                [X+Xn+1.9*Xtwidth+dX-dX...
                                  *(k-2),Y,...
                                 1.2*Xtwidth,Ytwidth]);
               htext3=uicontrol('Parent',hp,...
                                'Style','text',...
                                'String','Plot',...
                                'Position',...
                                [X+Xn+3*Xtwidth+dX-dX...
                                  *(k-2),Y,...
                                 0.5*Xtwidth,Ytwidth]);
                
               %  Construct the components.
           end
           m=m+1; %component
           if m<=component
               row=MU_MODEL.COMPONENT(m).PARAMETERNUMBER;
               Px=X/Xwidth;
               X0=0;  % Starting relative coord for param inside panel hps 
               Py=(Y-row*totY)/Ywidthpar;
               Y0=dY; % Starting relative coord for param inside panel hps
               PWx=(totX+5*dX)/Xwidth;
               PWy=(Y+1.8*Ytwidth)/Ywidthpar-Py;
               % [X Y row row*(totY+dY)+dY]
               %               if m==1, Py=(Y-4*totY)/Ywidth; end
               hps=uipanel('Parent',hp,'Title','',...
                           'Position',[Px Py PWx PWy]);

               ffton=[ffton m];
               
               Tag=num2str(m); % String=Tag=component
               htext0=uicontrol('Parent',hps,...
                                'Style','text',...
                                'String','FFT',...
                                'Horizontalalignment','Left',...
                                'Position',...
                                [X0+Xbwidth+2*dX,Y0+row*totY,1.5*Xbwidth,Ytwidth]);
               hFFTb=uicontrol('Parent',hps,...
                               'Style','checkbox',...
                               'String',Tag,...
                               'Callback',@FFTOn_CallBack,...
                               'Value',1,... 
                               'Position',...
                               [X0+dX,Y0+row*totY,Xbwidth,Ytwidth]);   
               X0=X0+dX;
              
               for l=1:row
                   Yr=Y0+(row-l)*totY;
                   p=p+1;
                   spar=int2str(p);
                   hnum = uicontrol('Parent',hps,...
                                    'Style','text',...
                                    'String',spar,...
                                    'Horizontalalignment','Right',...
                                    'Position',...
                                    [X0,Yr,Xn,Ytwidth]);
                   name=[char(MU_MODEL.COMPONENT(m).NAME) ...
                         char(MU_MODEL.COMPONENT(m).PARAMETER(l).NAME)];
                   hname = uicontrol('Parent',hps,...
                                     'Style','text',...
                                     'String',name,...
                                     'Horizontalalignment','Left',...
                                     'Position',...
                                     [X0+Xn+dX,Yr,Xtwidth,Ytwidth]);
                   tag=['Value' spar];
                   menutags.tag(3*(p-1)+1+Nmenumenu)={tag};
                   value=MU_MODEL.COMPONENT(m).PARAMETER(l).VALUE;
                   flag=MU_MODEL.COMPONENT(m).PARAMETER(l).FLAG;
                   if flag=='='&&isfield(...
                       MU_MODEL.COMPONENT(m).PARAMETER(l),'SHARE')
                       nn=MU_MODEL.COMPONENT(m).PARAMETER(l).SHARE;
                       [ss cc pp]=mucomp(nn);
                       flag=[flag num2str(nn)];
                       value= ...
                           MU_MODEL.COMPONENT(cc).PARAMETER(pp) ...
                           .VALUE;
                   elseif flag=='+'&&isfield(...
                       MU_MODEL.COMPONENT(m).PARAMETER(l),'LINREL')
                       value=0;
                       flag=[flag ...
                             MU_MODEL.COMPONENT(m).PARAMETER(l).LINREL];
                   end
                   hvalue = uicontrol('Parent',hps,...
                                      'Style','Edit',...
                                      'Tag',tag,...
                                      'String',value,...
                                      'Callback',@Menu_CallBack,...
                                      'Horizontalalignment','Left',...
                                      'Position',...
                                      [X0+Xn+0.9*Xtwidth+2*dX,Yr,...
                                       Xtwidth,Ytwidth],...
                                      'Backgroundcolor','white');
                   tag=['Flag' spar];
                   menutags.tag(3*(p-1)+2+Nmenumenu)={tag};
                   hlin = uicontrol('Parent',hps,...
                                    'Style','Edit',...
                                    'Tag',tag,...
                                    'String',flag,...
                                    'Horizontalalignment','Left',...
                                    'Callback',@Menu_CallBack,...
                                   'Position',....
                                    [X0+Xn+1.9*Xtwidth+3*dX,Yr,...
                                     Xtwidth,Ytwidth],...
                                    'Backgroundcolor','white');
                   tag=['Plotpar' spar];
                   if isfield(MU_MODEL.COMPONENT(m).PARAMETER(l),'PLOT')
                       value= ...
                           MU_MODEL.COMPONENT(m).PARAMETER(l).PLOT;
                   else
                       value=5;
                       MU_MODEL.COMPONENT(m).PARAMETER(l).PLOT=5;
                   end
                   if isempty(value)
                       value=5;
                       MU_MODEL.COMPONENT(m).PARAMETER(l).PLOT=5;
                   end
                   
                   plotpanel={'1' '2' '3' '4' '0'};
                   menutags.tag(3*p+Nmenumenu)={tag};
                   hlin = uicontrol('Parent',hps,...
                                    'Style','popupmenu',...
                                    'Tag',tag,...
                                    'String',plotpanel,...
                                    'Value',value,...
                                    'Callback',@Menu_CallBack,...
                                    'Position',....
                                    [X0+Xn+2.9*Xtwidth+3*dX,Yr,...
                                     0.5*Xtwidth,Ytwidth],...
                                    'Backgroundcolor','white');

               end
           end
           menutags.FFTOn=ffton;
       end
   end
   buttoncolor=[0.7 0.7 0.8];
   set(hfit,'Visible','on','Backgroundcolor',buttoncolor)
   guidata(MU_FIG.MENU,menutags);
   
   %Make the GUI visible.
    Screen=get(0, ...
                                                    'ScreenSize');
    XScreenWidth=Screen(3);
    YScreenWidth=Screen(4);
    Position=get(MU_FIG.MENU,'Position');
    XWidth=Position(3);
    YWidth=Position(4);
    XFactor=XWidth/XScreenWidth;
    XFrame=round(XScreenWidth*XFactor*0.05);
    YFactor=YWidth/YScreenWidth;
    YFrame=round(YScreenWidth*YFactor*0.07);
    XPosition=XScreenWidth-XWidth-XFrame;
    YPosition=YScreenWidth-YWidth-YFrame;
    set(MU_FIG.MENU,'Position',[XPosition ...
                        YPosition ...
                        XWidth YWidth]);
   set(MU_FIG.MENU,'Visible','on','handlevisibility','callback');
%   refresh(htogglebatch)

function Menu_CallBack(varargin)
    global MU_MODEL MU_MODEL_F MU_PATH MU_GEAR MU_DATA MU_FIG MU_ADD
    string=[];
    
    existsmodel=isfield(MU_MODEL,'NAME');
    if existsmodel
        [p d name]=mupar(1); % retrieves parameter values 
                             % previously stored in MU_MODEL (for
                             % comparison and fallback
    end
    
    hstrike=cell2mat(varargin(1)); %this is the handle of the last
                                   %touched object
    h=guihandles; % this structure contains the handles of all
                  % the objects 
    menutags=guidata(gcf); % cell array with tags of each object 
    % menutags.tag
    % disp(['LineBroa is ' char(menutags.tag(27)) ' with handle '...
    % num2str(getfield(h,char(menutags.tag(27)))) ...
    % ' cfr. hstrike=' num2str(hstrike)]) %RDR
    for k=1:length(menutags.tag)
        string=cell2mat(menutags.tag(k));
        if ~isempty(string)
            hh=getfield(h,string); % handle of each
                                   % successive object
            if hh==hstrike
                kstrike=k;% this is the handle of the striken object
            end
        end
    end
    if exist('kstrike')
        string=cell2mat(menutags.tag(kstrike)); % this is the tag of the
                                            % striken object
    end
    if findstr(string,'Valu')
        %disp(['Was a paramenter value. The new value is ' ...
        %      get(hstrike,'String')])
        n=str2num(string(6:end)); % order number in menu list
        [s c p]= mucomp(n); % c is component number, p parameter
                            % number
        MU_MODEL.COMPONENT(c).PARAMETER(p).VALUE=...
            str2num(get(hstrike,'String'));
    elseif findstr(string,'Flag')
        n=str2num(string(5:end)); % order number in menu list
        [s c p]= mucomp(n); % c is component number, p parameter
                            % number
        s=get(hstrike,'String'); % this is the second input (~!=+)
        s=deblank(s);
        if ~isempty(s)
            OK=muextractflag(s,n); % if correct stores the values
            if OK
                set(hstrike,'Backgroundcolor',[1 1 1]);
                nn=MU_MODEL.COMPONENT(c).PARAMETER(p).SHARE;
                % code:  nn==n for !~, nn=0 for +, nn~=n,0 for =  
                if ~nn % nn=0 is a valid linear relation
                       % checked by muparse within muextractflag
                       % should calculate value according to LINREL
                       % update it. However this means
                       % recalculating values each time one
                       % parameter is changed, in case it is used
                       % by a LINEAR RELATION. Too much hassle!
                       % put instead this value to a conventional
                       % zero (already done in muextractflag)
                     hhh=getfield(h,['Value' num2str(n)]); % handle of value
                    set(hhh,'String',...
                            MU_MODEL.COMPONENT(c).PARAMETER(p).VALUE)
                   
                elseif nn~=n % means it is a SHARE
                    [s cc pp]=mucomp(nn);  % component and
                                           % parameter indices of
                                           % shared par
                    hhh=getfield(h,['Value' num2str(n)]); % handle of value
                    set(hhh,'String',...
                            MU_MODEL.COMPONENT(cc).PARAMETER(pp).VALUE)
                end
            else % not OK, rewrites old value
                set(hstrike,'String',...
                            MU_MODEL.COMPONENT(c).PARAMETER(p).FLAG,...
                            'Backgroundcolor',[1 0.9 0.9]);
            end
        else  % empty, rewrites old value
            set(hstrike,'String',MU_MODEL.COMPONENT(c).PARAMETER(p).FLAG,...
                        'Backgroundcolor',[1 0.9 0.9]);            
        end
    elseif findstr(string,'Plotpar')
        % stores value for plots of parameters
        n=str2num(string(8:end)); % order number in menu list
        [s c p]= mucomp(n); % c is component number, p parameter
        s=get(hstrike,'Value');
        if s>=1&s<5
            MU_MODEL.COMPONENT(c).PARAMETER(p).PLOT=s;
        elseif s==5
            MU_MODEL.COMPONENT(c).PARAMETER(p).PLOT=0;
        end
    else
        switch string
          case 'Fgroup'
            MU_MODEL.GROUPING.FORWARD=...
                mugroup(get(hstrike,'String'));
            %disp([string ' new value ' get(hstrike,'String')])
                            % update Total menus
            if isfield(MU_DATA,'DATA')
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
                string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
                htot=getfield(h,'Total');
                set(htot,'Label',string);
                if isfield(MU_MODEL,'NAME')
                    group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                    ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                    string=['Group total counts ' num2str(ntot/1e6,3) ' Mev'];
                    hgrouptot=getfield(h,'GroupTotal');
                    set(hgrouptot,'Label',string);
                end
            end
          case 'Bgroup'
            MU_MODEL.GROUPING.BACKWARD=...
                mugroup(get(hstrike,'String'));
            %disp([string ' new value ' get(hstrike,'String')])
                          % update Total menus
            if isfield(MU_DATA,'DATA')
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
                string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
                htot=getfield(h,'Total');
                set(htot,'Label',string);
                if isfield(MU_MODEL,'NAME')
                    group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                    ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                    string=['Group total counts ' num2str(ntot/1e6,3) ' Mev'];
                    hgrouptot=getfield(h,'GroupTotal');
                    set(hgrouptot,'Label',string);
                end
            end
            
          case 'Alpha'
            [alpha ok]=str2num(get(hstrike,'String'));
            if ok&~isempty(alpha)
                MU_MODEL.ALPHA=alpha;
            else
                set(hstrike,'String',MU_MODEL.ALPHA);
            end
            %disp([string ' new value ' get(hstrike,'String')])
          case 'Bin'
            [bin ok]=str2num(get(hstrike,'String'));
            if ok&~isempty(bin)
                MU_MODEL.BIN=bin;
            else
                set(hstrike,'String',MU_MODEL.BIN);
            end
            %disp([string ' new value ' get(hstrike,'String')])
          case 'Range'
            [range ok]=str2num(get(hstrike,'String'));
            if ~isfield(MU_DATA,'DATA')
                ok=0;
            else
                nt0=max(MU_DATA.NT0);
                lmax=length(MU_DATA.DATA)...
                -MU_GEAR.OFFSET-nt0;
                if isempty(range)|range(1)>=range(2)|...
                    range(1)<1|range(2)>=lmax
                    ok=0;
                    disp('Illegal fit range, was reset.')
                end
            end
            if ok
                MU_MODEL.RANGE=range;
            else
                set(hstrike,'String',num2str(MU_MODEL.RANGE));
            end
            %disp([string ' new value ' get(hstrike,'String')])
          case 'NextRun'
             [nrun ok]=str2num(get(hstrike,'String'));
             OK=mucanload(nrun);
            if ok&&~isempty(nrun)&&OK
                set(hstrike,...
                    'Backgroundcolor',[1 1 1]);
            else
                set(hstrike,'String',num2str(MU_DATA.NRUN+1),...
                            'Backgroundcolor',[1 0.9 0.9]);
            end           
            %disp([string ' new value ' get(hstrike,'String')])
          case 'Fit'
            mufit
            %disp([string ' new value ' get(hstrike,'String')])
          case 'Auto'
            value=get(hstrike,'String');
            MU_MODEL.BATCHMODE=value(get(hstrike,'Value'));
            %value=value(get(hstrike,'Value'));
            %disp([string ' new value ' value])
          case 'Denom'
            value=get(hstrike,'String');
            MU_MODEL.FLAG.DENOMINATOR=char(value(get(hstrike,'Value')));
            %value=value(get(hstrike,'Value'));
            %disp([string ' new value ' value])
          case 'LoadModel'
            Tag=cell2mat(menutags.tag(12));
            modelnamehandle=getfield(h,Tag); % handle of each
            modelname=get(modelnamehandle,'String');
            if ~isempty(modelname);
                set(modelnamehandle,'String',[]); % reset ModelName to
                                                  % empty, to prevent 
                                                  % overwriting 
                                                  % the present model 
                mucreatemodel(modelname)
            else
                ok=muldmodel;
                if ok 
                    mufit_gui % force re-layout 
                end
            end
            % disp([string ' new value ' get(hstrike,'String')])
          case 'EdModel'
            mueditmodel(1);
            % mufit_gui(1)              
            % disp([string ' new value ' get(hstrike,'String')])
          case 'ModelName'
            name=get(hstrike,'String');
            % input was given, check it
            if ~isempty(name)
                if(~muvalidatemodel(name)); % if invalid
                                                % restore empty
                    set(hstrike,'String','');
                    disp('Invalid model name in LdModel input') 
                 end
            end
          case 'Path'
            mucd
            if isfield(MU_PATH,'DATA')
                hdatadir=getfield(h,'DataDir');
                set(hdatadir,'String',MU_PATH.DATA);
            end
          case 'AddPrev'
            Tag=cell2mat(menutags.tag(6));
            hnextrun=getfield(h,Tag); % handle of each
            if mucanload(MU_DATA.NRUN-1)
                muadd(-1)             
            else
                disp(['**** Warning! Run ' num2str(nrun) ' does ' ...
                      'not exist'])
                return
            end
            % update Total menus
            ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
            string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
            htot=getfield(h,'Total');
            set(htot,'Label',string);
            if isfield(MU_MODEL,'NAME')
                group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                string=['Group total counts ' num2str(ntot/1e6,3) ' Mev'];
                hgrouptot=getfield(h,'GroupTotal');
                set(hgrouptot,'Label',string);
            end
            % update title strip
            htxtdata=getfield(h,'RunTitle');
            runs=int2str(MU_DATA.NRUN);
            arun=num2str(MU_ADD(1));
            for k=2:length(MU_ADD)
                arun=[arun '+' num2str(MU_ADD(k))];
            end
            runs=[int2str(MU_DATA.NRUN) '+' arun];
            string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
                    deblank(MU_DATA.ORIENTATION) ' ' ...
                    ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
                    ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
            set(htxtdata,'String',string);
            % update Next run
            if mucanload(MU_ADD(end)+1)
                set(hnextrun,'String',num2str(MU_ADD(end)+1),...
                             'Backgroundcolor',[1 1 1]);
            else
                set(hnextrun,'String',[],...
                             'Backgroundcolor',[1 0.9 0.9]);
                %                    msgbox(['Next run' num2str(MU_ADD(end)+1)...
                %        ' is missing'],'Add','non-modal')
            end         

          case 'AddNext'
            %determine the handle of 'Next run'
            Tag=cell2mat(menutags.tag(6));
            hnextrun=getfield(h,Tag); % handle of each
            %determine the content of 'Next run'
            [nrun ok]=str2num(get(hnextrun,'String'));
            if ok
                n=nrun-MU_DATA.NRUN;
                muadd(n)            
                % update Total menus
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
                string=['Tot ' num2str(ntot/1e6,3) ' Mev'];
                htot=getfield(h,'Total');
                set(htot,'Label',string);
                if isfield(MU_MODEL,'NAME')
                    group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                    ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                    string=['Group Tot ' num2str(ntot/1e6,3) ' Mev'];
                    hgrouptot=getfield(h,'GroupTotal');
                    set(hgrouptot,'Label',string);
                end
                % update title strip
                htxtdata=getfield(h,'RunTitle');
                runs=int2str(MU_DATA.NRUN);
                arun=num2str(MU_ADD(1));
                for k=2:length(MU_ADD)
                    arun=[arun '+' num2str(MU_ADD(k))];
                end
                runs=[int2str(MU_DATA.NRUN) '+' arun];
                string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
                        deblank(MU_DATA.ORIENTATION) ' ' ...
                        ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
                        ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
                set(htxtdata,'String',string);
                % update Next run
                if mucanload(MU_ADD(end)+1)
                    set(hnextrun,'String',num2str(MU_ADD(end)+1),...
                                 'Backgroundcolor',[1 1 1]);
                else
                    set(hnextrun,'String',[],...
                                 'Backgroundcolor',[1 0.9 0.9]);
                end         
            else
                disp('***** Warning! Next run is not defined')
            end
          case 'AddGui'
            Tag=cell2mat(menutags.tag(6));
            hnextrun=getfield(h,Tag); % handle of each
            muadd
            % update Total menus
            ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
            string=['Tot ' num2str(ntot/1e6,3) ' Mev'];
            htot=getfield(h,'Total');
            set(htot,'Label',string);
            if isfield(MU_MODEL,'NAME')
                group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                string=['Group Tot ' num2str(ntot/1e6,3) ' Mev'];
                hgrouptot=getfield(h,'GroupTotal');
                set(hgrouptot,'Label',string);
            end
            % update title strip
            htxtdata=getfield(h,'RunTitle');
            runs=int2str(MU_DATA.NRUN);
            arun=num2str(MU_ADD(1));
            for k=2:length(MU_ADD)
                arun=[arun '+' num2str(MU_ADD(k))];
            end
            runs=[int2str(MU_DATA.NRUN) '+' arun];
            string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
                    deblank(MU_DATA.ORIENTATION) ' ' ...
                    ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
                    ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
            set(htxtdata,'String',string);
            % update Next run
            if mucanload(MU_ADD(end)+1)
                set(hnextrun,'String',num2str(MU_ADD(end)+1),...
                             'Backgroundcolor',[1 1 1]);
            else
                set(hnextrun,'String',[],...
                            'Backgroundcolor',[1 0.9 0.9]);
            end          
            %disp([string ' new value ' get(hstrike,'String')])
          case 'LoadNext'
            %determine the handle of 'Next run'
            Tag=cell2mat(menutags.tag(6));
            hnextrun=getfield(h,Tag); % handle of each
            %determine the content of 'Next run'
            [nrun ok]=str2num(get(hnextrun,'String'));
            if ok
               n=nrun-MU_DATA.NRUN;
                muload(n) 
                global MU_DATA
                % update Total menus
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
                string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
                htot=getfield(h,'Total');
                set(htot,'Label',string);
                if isfield(MU_MODEL,'NAME')
                    group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                    ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                    string=['Group total counts ' num2str(ntot/1e6,3) ' Mev'];
                    hgrouptot=getfield(h,'GroupTotal');
                    set(hgrouptot,'Label',string);
                end
                % update title strip
                htxtdata=getfield(h,'RunTitle');
                runs=int2str(MU_DATA.NRUN);
                string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
                        deblank(MU_DATA.ORIENTATION) ' ' ...
                        ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
                        ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
                set(htxtdata,'String',string);
                if mucanload(MU_DATA.NRUN+1)
                    set(hnextrun,'String',num2str(MU_DATA.NRUN+1),...
                                 'Backgroundcolor',[1 1 1]);
                else
                    set(hnextrun,'String',[],...
                                 'Backgroundcolor',[1 0.9 0.9]);
                end

                stringstart=['Started ' MU_DATA.START_DATE ...  
                             ',' MU_DATA.START_TIME];
                stringstop=['Saved ' MU_DATA.STOP_DATE ...  
                            ',' MU_DATA.STOP_TIME];
                comment=deblank(MU_DATA.COMMENTS);

                stringnsbin=['ns/bin ' num2str(MU_DATA.RESNS)];
                hnsbin=getfield(h,'NsBin');
                set(hnsbin,'Label',stringnsbin)
                hstartdate=getfield(h,'StartDate');
                set(hstartdate,'Label',stringstart)
                hstopdate=getfield(h,'StopDate');
                set(hstopdate,'Label',stringstop)
                hcomment=getfield(h,'Comment');
                set(hcomment,'Label',comment)
            else
                disp('WARNING! Next run is not defined')
            end
          case 'LoadPrev'
            Tag=cell2mat(menutags.tag(6));
            hnextrun=getfield(h,Tag); % handle of each
            if mucanload(MU_DATA.NRUN-1) 
                muload(-1) 
            else
                disp(['**** Warning! Run ' num2str(nrun) ' does ' ...
                      'not exist'])
                return
            end
            global MU_DATA
            % update Total menus
            ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
            string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
            htot=getfield(h,'Total');
            set(htot,'Label',string);
            if isfield(MU_MODEL,'NAME')
                group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                string=['Group total counts ' num2str(ntot/1e6,3) ' Mev'];
                hgrouptot=getfield(h,'GroupTotal');
                set(hgrouptot,'Label',string);
            end
            % update title strip
            htxtdata=getfield(h,'RunTitle');
            runs=int2str(MU_DATA.NRUN);
            string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
                    deblank(MU_DATA.ORIENTATION) ' ' ...
                    ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
                    ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
            set(htxtdata,'String',string);
            if mucanload(MU_DATA.NRUN+1)
                set(hnextrun,'String',num2str(MU_DATA.NRUN+1),...
                             'Backgroundcolor',[1 1 1]);
            else
                set(hnextrun,'String',[],...
                             'Backgroundcolor',[1 0.9 0.9]);
            end
            stringstart=['Started ' MU_DATA.START_DATE ...  
                         ',' MU_DATA.START_TIME];
            stringstop=['Saved ' MU_DATA.STOP_DATE ...  
                        ',' MU_DATA.STOP_TIME];
            comment=deblank(MU_DATA.COMMENTS);

            stringnsbin=['ns/bin ' num2str(MU_DATA.RESNS)];
            hnsbin=getfield(h,'NsBin');
            set(hnsbin,'Label',stringnsbin)
            hstartdate=getfield(h,'StartDate');
            set(hstartdate,'Label',stringstart)
            hstopdate=getfield(h,'StopDate');
            set(hstopdate,'Label',stringstop)
            hcomment=getfield(h,'Comment');
            set(hcomment,'Label',comment)

          case 'LoadGui'
            Tag=cell2mat(menutags.tag(6));
            hnextrun=getfield(h,Tag); % handle of each
            muload
            global MU_DATA
            % update Total menus
            ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
            string=['Total counts ' num2str(ntot/1e6,3) ' Mev'];
            htot=getfield(h,'Total');
            set(htot,'Label',string);
            if isfield(MU_MODEL,'NAME')
                group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
                ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
                string=['Group Total counts ' num2str(ntot/1e6,3) ' Mev'];
                hgrouptot=getfield(h,'GroupTotal');
                set(hgrouptot,'Label',string);
            end
            htxtdata=getfield(h,'RunTitle');
            runs=int2str(MU_DATA.NRUN);
            string=[runs ' ' deblank(MU_DATA.SAMPLE) ' ' ...
                    deblank(MU_DATA.ORIENTATION) ' ' ...
                    ' ' num2str(str2num(MU_DATA.TEMPERATURE(1:end-1))) 'K'...
                    ' ' num2str(str2num(MU_DATA.FIELD(1:end-1))) 'G'];
            set(htxtdata,'String',string);            
            if mucanload(MU_DATA.NRUN+1)
                set(hnextrun,'String',num2str(MU_DATA.NRUN+1),...
                            'Backgroundcolor',[1 1 1]);
            else
                set(hnextrun,'String',[],...
                            'Backgroundcolor',[1 0.9 0.9]);
            end
            stringstart=['Started ' MU_DATA.START_DATE ...  
                         ',' MU_DATA.START_TIME];
            stringstop=['Saved ' MU_DATA.STOP_DATE ...  
                        ',' MU_DATA.STOP_TIME];
            comment=deblank(MU_DATA.COMMENTS);

            stringnsbin=['ns/bin ' num2str(MU_DATA.RESNS)];
            hnsbin=getfield(h,'NsBin');
            set(hnsbin,'Label',stringnsbin)
            hstartdate=getfield(h,'StartDate');
            set(hstartdate,'Label',stringstart)
            hstopdate=getfield(h,'StopDate');
            set(hstopdate,'Label',stringstop)
            hcomment=getfield(h,'Comment');
            set(hcomment,'Label',comment)

          case 'LogVersion'
             string=char(get(hstrike,'String')); % edited value 
             MU_MODEL.FLAG.LOGVERSION=string;
          case 'Update' 
            muupdatemodel
            close(MU_FIG.MENU)
            mufit_gui
          case 'PlotFit'
            string=char(menutags.PlotFitRange);
            if isempty(deblank(string))
                muplotfit(menutags.PlotFitParameters)
            else
                muplotfit(menutags.PlotFitParameters,...
                          str2num(menutags.PlotFitRange));
            end
          case 'PlotFitRange'
            menutags.PlotFitRange=get(hstrike,'String');
            guidata(gcf,menutags)
          case 'PlotFitParameters'
            menutags.PlotFitParameters=get(hstrike,'Value');
            guidata(gcf,menutags)
          case 'FftResidues'
            if ~isfield(MU_MODEL_F,'CHI')
                msgbox('Execute a fit first!','FFT of residues','non-modal')
                return
            else
                %                Tag=cell2mat(menutags.tag(27));
                %linebroadhandle=getfield(h,Tag); % handle of each
                %menutags.LineBroadening=get(linebroadhandle,'String');
                %Tag=cell2mat(menutags.tag(26));
                %fftrangehandle=getfield(h,Tag); % handle of each
                %menutags.FFTRange=get(fftrangehandle,'String');
                
                lb=str2num(menutags.LineBroadening);
                if isempty(lb), lb=0; end
                range=str2num(menutags.FFTRange);
                if isempty(range)
                    mufftres(lb,menutags.FFTOn);
                else
                    mufftres(lb,...
                             menutags.FFTOn,...
                             range)
                end
            end
          case 'FFTRange'
             menutags.FFTRange=char(get(hstrike,'String')); 
             guidata(gcf,menutags)            
          case 'LineBroadening'
             menutags.LineBroadening=char(get(hstrike,'String')); 
             guidata(gcf,menutags)
          otherwise
            disp(['Broken code? Unknown tag in Menu_CallBack in ' ...
                  'MUFIT_GUI:'])
            disp(['      ' menutags.tag(kstrike)])
        end
    end   

function Rig_CallBack(varargin)
    
% tagmenu=[ 'PSIASCII' 'PSIBIN' 'ISISMCS' 'ISISNXS' ...
%          'GPS' 'LTF' 'DOLLY' 'MUS64' 'MUS' 'EMU'};
    
h=guihandles; % this structure contains are the handles of all
                  % the objects 
global MU_GEAR MU_DATA MU_FIG
red=[0.8 0.2 0.2];
white=[1 1 1];
black=[0 0 0];

tagmenu={ 'PSIASCII' 'PSIBIN' 'ISISMCS' 'ISISNXS' ...
          'GPS' 'LTF' 'DOLLY' 'MUS64' 'MUS' 'EMU'};

hstrike=cell2mat(varargin(1)); %this is the handle of the last
   handles=[];
   for tag=tagmenu
       string=cell2mat(tag);
       handles=[handles getfield(h,string)];
   end
   hPSI=getfield(h,'PSImenu');
   hISIS=getfield(h,'ISISmenu');
   switch hstrike
     case handles(1) % PSI ASCII
       facility=MU_GEAR.FACILITY;
       data_type=MU_GEAR.DATA_TYPE;
       oldhandle=getfield(h,[facility data_type]);
       set(oldhandle,'Foregroundcolor',black)
       set(hPSI,'Visible','on')
       set(hISIS,'Visible','off')
       set(handles(1),'Foregroundcolor',red);

       MU_GEAR.FACILITY='PSI';
       MU_GEAR.DATA_TYPE='ASCII';
       MU_GEAR.FILENAME_SUFFIX='dat';
       %             string='PSI ASCII';
       %             disp([string ' is new value '])
     case handles(2) % PSI BIN
       facility=MU_GEAR.FACILITY;
       data_type=MU_GEAR.DATA_TYPE;
       oldhandle=getfield(h,[facility data_type]);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','on')
       set(hISIS,'Visible','off')
       set(handles(2),'Foregroundcolor',red);

       MU_GEAR.FACILITY='PSI';
       MU_GEAR.DATA_TYPE='BIN';
       MU_GEAR.FILENAME_SUFFIX='bin';
       %      string='PSI BIN';
       %      disp([string ' is new value '])
     case handles(3) % ISIS MCS
       facility=MU_GEAR.FACILITY;
       data_type=MU_GEAR.DATA_TYPE;
       oldhandle=getfield(h,[facility data_type]);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','off')
       set(hISIS,'Visible','on')
       set(handles(3),'Foregroundcolor',red);

       MU_GEAR.FACILITY='ISIS';
       MU_GEAR.DATA_TYPE='MCS';
       MU_GEAR.FILENAME_SUFFIX='raw';
                     %string='ISIS MCS';
                     %disp([string ' is new value '])
     case handles(4) % ISISNXS
       facility=MU_GEAR.FACILITY;
       data_type=MU_GEAR.DATA_TYPE;
       oldhandle=getfield(h,[facility data_type]);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','off')
       set(hISIS,'Visible','on')
       set(handles(4),'Foregroundcolor',red);

       MU_GEAR.FACILITY='ISIS';
       MU_GEAR.DATA_TYPE='NEXUS';
       MU_GEAR.FILENAME_SUFFIX='nxs';
                     %string='ISIS NXS';
                     %disp([string ' is new value '])
     case handles(5) % GPS
       instrument=MU_GEAR.INSTRUMENT;
       oldhandle=getfield(h,instrument);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','on')
       set(hISIS,'Visible','off')
       set(handles(5),'Foregroundcolor',red);

       MU_GEAR.INSTRUMENT='GPS';
       %MU_GEAR.FILENAME_PREFIX='gps';
       %       string='GPS';
       %       disp([string ' is new value '])
     case handles(6) % LTF
       instrument=MU_GEAR.INSTRUMENT;
       oldhandle=getfield(h,instrument);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','on')
       set(hISIS,'Visible','off')
       set(handles(6),'Foregroundcolor',red);

       MU_GEAR.INSTRUMENT='LTF';
       %MU_GEAR.FILENAME_PREFIX='ltf';
                     %       string='LTF';
                     %       disp([string ' is new value '])
     case handles(7) % DOLLY
       instrument=MU_GEAR.INSTRUMENT;
       oldhandle=getfield(h,instrument);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','on')
       set(hISIS,'Visible','off')
       set(handles(7),'Foregroundcolor',red);

       MU_GEAR.INSTRUMENT='DOLLY';
       %MU_GEAR.FILENAME_PREFIX='dol';
       %       string='DOLLY';
       %       disp([string ' is new value '])
     case handles(8) % MUS64
       instrument=MU_GEAR.INSTRUMENT;
       oldhandle=getfield(h,instrument);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','off')
       set(hISIS,'Visible','on')
       set(handles(8),'Foregroundcolor',red);

       MU_GEAR.INSTRUMENT='MUS64';
       %MU_GEAR.FILENAME_PREFIX='mus';
       %       string='MUS64';
       %       disp([string ' is new value '])
     case handles(9) % MUS
       instrument=MU_GEAR.INSTRUMENT;
       oldhandle=getfield(h,instrument);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','off')
       set(hISIS,'Visible','on')
       set(handles(9),'Foregroundcolor',red);

       MU_GEAR.INSTRUMENT='MUS';
       %MU_GEAR.FILENAME_PREFIX='mus';
       %       string='MUS32';
       %       disp([string ' is new value '])
     case handles(10) % EMU
       instrument=MU_GEAR.INSTRUMENT;
       oldhandle=getfield(h,instrument);
       set(oldhandle,'Foregroundcolor',black);
       set(hPSI,'Visible','off')
       set(hISIS,'Visible','on')
       set(handles(10),'Foregroundcolor',red);

       MU_GEAR.INSTRUMENT='EMU';
       %MU_GEAR.FILENAME_PREFIX='emu';
       string='EMU';
       disp([string ' is new value '])
   end
       
function Save_CallBack(varargin)

    global MU_FIG MU_GEAR
% tagmenu={ 'SAVEMULAB' 'LOCATION' 'PREFIX' 'AUTOLOGPATH' 'QUIT'};

h=guihandles; % this structure contains are the handles of all
                  % the objects 
tagmenu={ 'SAVEMULAB' 'LOCATION' 'PREFIX' 'AUTOLOGPATH' 'QUIT'};
hstrike=cell2mat(varargin(1)); %this is the handle of the last
handles=[];
for tag=tagmenu
    string=cell2mat(tag);
    handles=[handles getfield(h,string)];
end

switch hstrike
  case handles(1) % SAVEMULAB
    mulabsave
  case handles(2) % LOCATION
  
    MU_GEAR.LOCATION=questdlg('Your location','WHERE AM I?',...
                              'ISIS','PSI','home','home');
    set(handles(2),'Label',['Set Location: [' MU_GEAR.LOCATION ']']);
  
  case handles(3) % PREFIX
    MU_GEAR.FILENAME_PREFIX=char(inputdlg('Filename prefix (e.g. deltat_pta_gps)','Data filename'));
    set(handles(3),'Label',['Set filename prefix:  [' ...
                        MU_GEAR.FILENAME_PREFIX ']']);
  case handles(4) % AUTOLOGPATH
    MU_GEAR.AUTOLOGPATH=questdlg('Log path is','LOG PATH',...
                                 'Selectable','Mirror','Selectable');
    set(handles(4),'Label',['Log path policy: [' ...
                        MU_GEAR.AUTOLOGPATH ']']);
    
  case handles(5) % QUIT
    Answer=questdlg('Clear globals for a fresh start?','Clear internal variables')
    switch Answer
        case 'Yes'
            close(MU_FIG.MENU)  
            clear global % to be able to start afresh
            disp('All globals (MU_DATA, MU_MODEL, MU_PATH,MU_GEAR etc. cleared')
        case 'No'
            close(MU_FIG.MENU)              
            disp('Globals (MU_DATA, MU_MODEL, MU_PATH,MU_GEAR etc. retained')
        otherwise
            disp('Quitting canceled')            
    end
end

function FFTOn_CallBack(varargin)
% must store the status of the first checkbox
% if on the corresponding component will be subtracted from the
% data in the FFT of residues
    global MU_MODEL

    source=cell2mat(varargin(1));
    menutags=guidata(gcf);
    ffton=menutags.FFTOn; % Stored old status of FFTOn, 
    n=str2num(get(source,'String')); % tells which component (which
                                     % checkbox) was stricken
    components=MU_MODEL.COMPONENTNUMBER;
    newffton=[];
    for k=1:components % rebuilds the list of components
        % doublechecks: 
        if k==n
            if ~get(source,'Value') &&...
                    ~isempty(find(ffton==n))
                % this one hes been switched off, do nothing
            elseif get(source,'Value') &&...
                    isempty(find(ffton==n))
                newffton=[newffton n];
                % this one hes been switched on, write it
            else
                msgbox('Corrupted FFT Radiobuttons','FFT Radio','non-modal')
            end
        elseif ~isempty(find(ffton==k)) %other components, preserve
            newffton=[newffton k];
        end
    end
    menutags.FFTOn=newffton;
    guidata(gcf,menutags)

function Plots_CallBack(varargin)    
global MU_PLOT    
global MU_DATA 

tagmenu={ 'PlotHisto' 'PlotT' 'PlotB' 'Plotx' 'PlotRun' 'PlotOver'};

h=guihandles;

hstrike=cell2mat(varargin(1)); %this is the handle of the last
                               %chosen menu item
handles=[];
for tag=tagmenu
    string=cell2mat(tag);
    handles=[handles getfield(h,string)];
end

switch hstrike
  case handles(1) % PlotHisto

    if ~isstruct(MU_DATA)
        msgbox('Load data first!','Plot raw','non-modal')
        return
    end
    
    if ~isfield(MU_PLOT,'RANGE')
        MU_PLOT.RANGE=[1 500];
    end
    if ~isfield(MU_PLOT,'HISTO')
        MU_PLOT.HISTO=1;
    end
    
    muplot(MU_PLOT.HISTO,MU_PLOT.RANGE)
  case handles(2) % PlotT
    muplotpar(1)
  case handles(3) % PlotB
    muplotpar(2)
  case handles(4) % Plotx
    muplotpar(3)
  case handles(5) % PlotRun
    muplotpar(4)
  case handles(6)
    MU_PLOT.NRUN_RESTORE=MU_DATA.NRUN; % to reload it al the end
    muplotover
end

function Setup_CallBack(varargin)
    
global MU_MODEL MU_PATH MU_GEAR MU_DATA

h=guihandles; % this structure contains are the handles of all
                  % the objects 
                  
                  switch MU_GEAR.INSTRUMENT
                      case {'GPS','LTF'}
                          tagmenu={ 'LoadGroups' 'SaveGroups' ...
                              'SetTime' 'Offsets' 'Sett0' ...
                              'Setdt' 'Mode' 'Bckg'};
                      otherwise
                          tagmenu={ 'LoadGroups' 'SaveGroups' ...
                              'SetTime' 'Offsets' 'Sett0' 'Setdt'};
                  end
% skipping Displayt0 and Displaydt which have no callback
hstrike=cell2mat(varargin(1)); %this is the handle of the last
                               %chosen menu item
handles=[];
for tag=tagmenu
    string=cell2mat(tag);
    handles=[handles getfield(h,string)];
end

switch hstrike
  case handles(1) % LoadGroups
    [filename path s]=uigetfile('.grp');
    if s
        load(filename,'-mat')
        MU_MODEL.GROUPING.FORWARD=MU_GROUP_FORWARD;
        MU_MODEL.GROUPING.BACKWARD=MU_GROUP_BACKWARD;
        MU_GEAR.OFFSET=MU_GROUP_OFFSET;
        disp(['File ' path filename ' loaded'])
        hFgroup=getfield(h,'Fgroup');
        hBgroup=getfield(h,'Bgroup');
        set(hFgroup,'String',musgroup(1,0));
        set(hBgroup,'String',musgroup(2,0));
        % now update offsets in menu dropdown
        string=['Offset (' num2str(MU_GEAR.OFFSET) ')'];
        hoffset=getfield(h,'Offsets');
        set(hoffset,'Label',string);
        % now update Total counts oin menu dropdown
        ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
        string=['Tot ' num2str(ntot/1e6,3) ' Mev'];
        htot=getfield(h,'Total');
        set(htot,'Label',string);
        if isfield(MU_MODEL,'NAME')
            group=[MU_MODEL.GROUPING.FORWARD MU_MODEL.GROUPING.BACKWARD];
            ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,group)));
            string=['Group Tot ' num2str(ntot/1e6,3) ' Mev'];
            hgrouptot=getfield(h,'GroupTotal');
            set(hgrouptot,'Label',string);
        end

    end
    if strcmp(pwd,MU_PATH.ROOTDIR)
        cd(MU_PATH.ROOTDIR)
    end
  case handles(2) % SaveGroups
    filename=inputdlg('Filename (no spec):','Saving groups file');
    MU_GROUP_FORWARD=MU_MODEL.GROUPING.FORWARD;
    MU_GROUP_BACKWARD=MU_MODEL.GROUPING.BACKWARD;
    MU_GROUP_OFFSET=MU_GEAR.OFFSET;
    filename=[char(filename) '.grp'];
    save(filename,'MU_GROUP_FORWARD','MU_GROUP_BACKWARD',...
         'MU_GROUP_OFFSET','-mat')
    disp(['File ' MU_PATH.ROOTDIR filename ' saved'])
  case handles(3) % SetTime
    muset
    ht0=getfield(h,'Displayt0');
    hdt=getfield(h,'Displaydt');
    if strcmp(MU_GEAR.FACILITY,'ISIS') %only one value for all
        set(ht0,'Label',['t0=(' int2str(MU_DATA.NT0(1)) ')']);
        set(hdt,'Label',['dt=(' num2str(MU_DATA.DT(1),'%0.2g') ')']);
    else
        set(ht0,'Label',['t0=(' int2str(MU_DATA.NT0) ')']);
        set(hdt,'Label',['dt=(' num2str(MU_DATA.DT,'%0.2g ') ')']);
    end
    
  case handles(4) % Offsets
    DefAns={num2str(MU_GEAR.OFFSET)};
    offset=inputdlg('First good bin from t=0 (prompt) :',...
                    'Offset',2,DefAns);
    MU_GEAR.OFFSET=str2num(char(offset));
    % now update offsets in menu dropdown
    string=['Offset (' num2str(MU_GEAR.OFFSET) ')'];
    hoffset=getfield(h,'Offsets');
    set(hoffset,'Label',string);
  case handles(5)  % set manually nt0
    
    dlg_title = 'Set t=0 bin';
    num_lines = 1;
    if strcmp(MU_GEAR.FACILITY,'ISIS') %only one value for all
        if exist('MU_DATA')            
            prompt = {'Enter integer bin number, nt0='};
            def = {int2str(MU_DATA.NT0(1))};
            answer=inputdlg(prompt,dlg_title,num_lines,def);
            MU_GEAR.NT0=str2num(char(answer))*ones(size(MU_DATA.NT0));
            MU_DATA.NT0=str2num(char(answer))*ones(size(MU_DATA.NT0));
            hdt=getfield(h,'Displayt0');
            set(hdt,'Label',['t0=(' char(answer) ')']);
        else
            disp('***** Load a run first!')
        end
    else
        if exist('MU_DATA')            
            nd = length(MU_DATA.NT0);
            prompt = {'Enter integer bin number, nt0(1)='};
            def = {int2str(MU_DATA.NT0(1))};
            for k=2:nd
                prompt=[prompt {['Enter integer bin number' ...
                                 ', nt0(' int2str(k) ')=']}];
                def=[def {int2str(MU_DATA.NT0(k))}];
            end
            answer=inputdlg(prompt,dlg_title,num_lines,def);
            nt0=reshape(str2num(char(answer)),1,nd);
            MU_GEAR.NT0=nt0;
            MU_DATA.NT0=nt0;
            hdt=getfield(h,'Displayt0');
            set(hdt,'Label',['t0=(' int2str(nt0) ')']);
       else
            disp('***** Load a run first!')
        end
    end
  case handles(6) % set manually dt
    dlg_title = 'Set -0.5<=dt<=0.5, ';
    num_lines = 1;
    if strcmp(MU_GEAR.FACILITY,'ISIS') %only one value for all
        if exist('MU_DATA')            
            prompt = {'Enter fraction of bin (fine-tune t=0), dt='};
            def = {int2str(MU_DATA.DT(1))};
            answer=inputdlg(prompt,dlg_title,num_lines,def);
            MU_GEAR.DT=str2num(char(answer))*ones(size(MU_GEAR.DT));            
            MU_DATA.DT=str2num(char(answer))* ...
                ones(size(MU_DATA.DT));
            hdt=getfield(h,'Displaydt');
            set(hdt,'Label',['dt=(' char(answer) ')']);
        else
            disp('***** Load a run first!')
        end
    else
        if exist('MU_DATA')            
            nd = length(MU_DATA.DT);
            prompt = {'Enter fraction of bin (fine-tune t=0), dt(1)='};
            def = {num2str(MU_DATA.DT(1),'%0.2g')};
            for k=2:nd
                prompt=[prompt {['Enter fraction of bin' ...
                                 ' (fine-tune t=0), dt(' int2str(k) ')=']}];
                def=[def {num2str(MU_DATA.DT(k),'%0.2g')}];
            end
            answer=inputdlg(prompt,dlg_title,num_lines,def);
            dt=reshape(str2num(char(answer)),1,nd);
            MU_DATA.DT=dt;
            MU_GEAR.DT=dt;
            hdt=getfield(h,'Displaydt');
            set(hdt,'Label',['dt=(' num2str(dt,'%0.2g ') ')']);
        else
            disp('***** Load a run first!')
        end
    end
  case handles(7) % mode
%        h260=uimenu(hsetup,'Label',['Toggle mode, now: ' MU_GEAR.MODE],...
%                   'Tag','Mode',...
%                   'Callback',@Setup_CallBack);
% this mode is only valid for GPS and it is used by muasymmetry to 
% subtract (NO MORE) or not (MORE) the background
    if strcmpi(MU_GEAR.MODE,'MORE')  % toggle from one 
        MU_GEAR.MODE='NO MORE'; % to the other
        mode=getfield(h,'Mode');
            set(mode,'Label',['Toggle mode, now: ' MU_GEAR.MODE]);      
    elseif strcmpi(MU_GEAR.MODE,'NO MORE') % toggle from the other 
        MU_GEAR.MODE='MORE'; % to the one
        mode=getfield(h,'Mode');
            set(mode,'Label',['Toggle mode, now: ' MU_GEAR.MODE]);
    end
  case handles(8) % bckg
 %          if  ~isfield(MU_GEAR,'BCKG')
 %             MU_GEAR.BCKG='PREPROMPT';
 %      end
 %      h260=uimenu(hsetup,'Label',['Toggle mode, now: ' MU_GEAR.BCKG],...
 %                  'Tag','Bckg',...
 %                  'Callback',@Setup_CallBack);
    if strcmpi(MU_GEAR.BCKG,'TAIL')  % toggle from one 
        MU_GEAR.BCKG='PREPROMPT'; % to the other
        mode=getfield(h,'Bckg');
        set(mode,'Label',['Toggle backg, now: ' MU_GEAR.BCKG]); 
    elseif strcmpi(MU_GEAR.BCKG,'PREPROMPT') % toggle from the other 
        MU_GEAR.BCKG='TAIL'; % to the one
        mode=getfield(h,'Bckg');
        set(mode,'Label',['Toggle backg, now: ' MU_GEAR.BCKG]);
        MU_GEAR.MODE='NO MORE'; % TAIL must subtract a background
        mode=getfield(h,'Mode');
        set(mode,'Label',['Toggle mode, now: ' MU_GEAR.MODE]);
    end

end


function Help_CallBack(varargin)
    
h=guihandles; % this structure contains are the handles of all
                  % the objects 
tagmenu={ 'Browser','Pathpolicy','Tzero','Model','ListComponents'};

hstrike=cell2mat(varargin(1)); %this is the handle of the last
                               %chosen menu item
handles=[];
for tag=tagmenu
    string=cell2mat(tag);
    handles=[handles getfield(h,string)];
end

switch hstrike
  case handles(1) % Browser
    stat=web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.Mulab','-browser');
    if stat
        disp('Your Matlab has problems finding/starting your browser')
        if isunix
            disp(['Try editing docopt.m in the toolbox/local/ ' ...
                  'directory'])
            disp('(you need root privilege for that)')
        end
        web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.Mulab')
    end
  case handles(2) % Path
    stat=web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.MulabDataLog','-browser');
    if stat
        disp('Your Matlab has problems finding/starting your browser')
        if isunix
            disp(['Try editing docopt.m in the toolbox/local/ ' ...
                  'directory'])
            disp('(you need root privilege for that)')
        end
        web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.MulabDataLog')
    end
  case handles(3) % Tzero
    stat=web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.MulabPrimer#tzero','-browser');
    if stat
        disp('Your Matlab has problems finding/starting your browser')
        if isunix
            disp(['Try editing docopt.m in the toolbox/local/ ' ...
                  'directory'])
            disp('(you need root privilege for that)')
        end
        web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.MulabPrimer#tzero')
    end
  case handles(4) % Model
    stat=web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.MulabPrimer#fit','-browser');
    if stat
        disp('Your Matlab has problems finding/starting your browser')
        if isunix
            disp(['Try editing docopt.m in the toolbox/local/ ' ...
                  'directory'])
            disp('(you need root privilege for that)')
        end
        web('http://www.fis.unipr.it/~roberto.derenzi/dispense/pmwiki.php?n=MuSR.MulabPrimer#fit')
    end      
  case handles(5) % ListComponents
mulistcomponents
end
