function [OK open close par]=muparse(linrel)
% This routine parses LINEAR RELATIONS: OK=1 if the syntax is correct
% LINREL is a command string 
%     like p(3)*0.34+p(7)-0.32 (the first + is omitted!)
% OPEN is the array of the indices of 'p('
% CLOSE is the array of the indices of ')'
% PAR is the array of FIT PARAMETERS MENU indices of SOURCE parameters
% each p must have ( and ), it may be followed by a *numerical and
% preceded by a sign, it may be followed by another such string, p
% or by a sum to a constant
% two indexing: 
%              according to Fit Parameters Menu (counts all) valid here
%              according to fminuit (counts only ~ and !)
%              recalculated in MUFIT

    
    global MU_MODEL
    OK=1;  % default is OK
           % look for parameters
    open=strfind(linrel,'p('); % look for parameters
    close=strfind(linrel,')'); % look for close parenthesis (each
                               % parameter must have one)
    l=length(open);
    if l==length(close) % as many 'p(' as ')'
        par=[];
        for k=1:l
            [m ok]=str2num(linrel(open(k)+2:close(k)-1)); % SOURCE index
            if ok
                [s kc kp]=mucomp(m);  
                if kp&strfind('~!',...
                           MU_MODEL.COMPONENT(kc).PARAMETER(kp) ...
                           .FLAG)
                    % if parameter SOURCE exists and is either 
                    % fixed or variable
                    par=[par m]; % store SOURCE parameter indices 
                else % includes the cases where n is <0, >maxpar,
                     % non integer
                    OK=0; % SOURCE is = or +
                    disp('--------------LINEAR RELATION ERROR-------')
                    disp(['   ' linrel])
                    disp(['    Invalid source index ' ...
                          linrel(open(k)+2:close(k)-1) ' or ' ...
                          'source parameter flag is =,+ '])
                end
            else
                OK=0; % was not an integer
                disp('--------------LINEAR RELATION ERROR-------')
                disp(['   ' linrel])
                disp('     Non existent source parameter')
            end
        end
    else
        disp('--------------LINEAR RELATION ERROR-------')
        disp(['   ' linrel])
        disp('     Mismatched p( )')
        disp('  Try variations of ''+-p(3)*0.666+p(6)*0.666-1.0'' ')
        OK=0; % mismatch between 'p(' and ')'
    end
    if OK
        try
            string=linrel;
            s='1.000';
            for k=1:l
                string(open(k):close(k))=s(1:close(k)-open(k)+1);
            end
            q=eval(string);
        catch
            OK=0;
            disp('--------------LINEAR RELATION ERROR-------')
            disp(['   ' linrel])
            disp('     Illegal syntax')
            disp('     Try variations of ''+-p(3)*0.666+p(6)*0.666-1.0'' ')
        end
    end
