function muplotover(varargin)
% usage MUPLOTOVER
%
% direct plot routine with command input interface
% to load and overlay asymmetries
% uses setting from mufit_gui when not specified
%
% usage MUPLOT(HISTO,RANGE) 
% HISTO = detector number, integer
% RANGE = start bin stop bin, integer array, e.g. [1 500]
global MU_DATA MU_FIG MU_MODEL MU_PLOT


if isempty(varargin)
    if ~isfield(MU_PLOT,'TRANGE')
        if ~isstruct(MU_DATA)
            disp('Please load some data first')
            return
        end
        if ~isstruct(MU_MODEL)
            disp('Please load a model first')
            return
        end
        
        if isfield(MU_MODEL,'RANGE')
            MU_PLOT.TRANGE=MU_MODEL.RANGE;
        else
            MU_PLOT.TRANGE=[1 size(MU_DATA.ASYMMETRY,2)];
        end
    end
    MU_PLOT.COLOR=1;
    fig_handle=figure(MU_FIG.PLOT);
    set(MU_FIG.PLOT,'Name',MU_FIG.PLOTNAME,'Visible','off',...
                    'MenuBar','None');
    clf
    runhandle=guidata(fig_handle); % creates data to be shared among different calls
    runhandle.temperature={MU_DATA.TEMPERATURE};
    runhandle.field={MU_DATA.FIELD}; 
    runhandle.xtext=0; % extra space for writing run and T, B
    guidata(fig_handle,runhandle) % saves
    colors=colormap(lines);
    Xmin=0.085;
    Ymin=0.1;
    Xwidth=0.8-Xmin;
    Ywidth=0.88-Ymin;
    hiamp=axes('position',[Xmin Ymin Xwidth Ywidth]);
    muasymmetry;
    [x,y]=murebin(MU_DATA.TIME(MU_PLOT.TRANGE(1):MU_PLOT.TRANGE(2)),...
            MU_DATA.ASYMMETRY(MU_PLOT.TRANGE(1):MU_PLOT.TRANGE(2)));
    plot(x,y,'color',colors(MU_PLOT.COLOR,:))
    MU_PLOT.COLOR=MU_PLOT.COLOR+1;
    hold(hiamp);
    xlabel(['Time (\mu s)'])
    ylabel('Asymmetry')
elseif cell2mat(varargin(1))==1
    colors=colormap(lines);
    fig_handle=figure(MU_FIG.PLOT);
    muasymmetry;
    [x,y]=murebin(MU_DATA.TIME(MU_PLOT.TRANGE(1):MU_PLOT.TRANGE(2)),...
            MU_DATA.ASYMMETRY(MU_PLOT.TRANGE(1):MU_PLOT.TRANGE(2)));
    plot(x,y,'color',colors(MU_PLOT.COLOR,:))
    ytext=1.02;
    runhandle=guidata(fig_handle); % gets stored value
    temperature=str2num(MU_DATA.TEMPERATURE(1:end-1));
    field=str2num(MU_DATA.FIELD(1:end-1));
    fsiz=11;  
    if ~strcmpi(runhandle.temperature,MU_DATA.TEMPERATURE)
        runhandle.temperature={MU_DATA.TEMPERATURE};
        xtext=0.02+runhandle.xtext;
        runhandle.xtext=runhandle.xtext+0.14; % space for writing the run number and T
        text(xtext,ytext,[num2str(MU_DATA.NRUN) ' ' strtrim(MU_DATA.TEMPERATURE)] ...
         ,'fontsize',fsiz,'fontweight','demi','color',colors(MU_PLOT.COLOR,:),...
         'units','normalized','clipping','off')
    elseif ~strcmpi(runhandle.temperature,MU_DATA.TEMPERATURE)
        runhandle.field={MU_DATA.FIELD};
        xtext=0.02+runhandle.xtext;
        runhandle.xtext=runhandle.xtext+0.12; % space for writing the run number and T
        text(xtext,ytext,[num2str(MU_DATA.NRUN) ' ' strtrim(MU_DATA.FIELD)] ...
         ,'fontsize',fsiz,'fontweight','demi','color',colors(MU_PLOT.COLOR,:),...
         'units','normalized','clipping','off')
    end
    guidata(fig_handle,runhandle); % updates the stored value
    MU_PLOT.COLOR=MU_PLOT.COLOR+1;
elseif cell2mat(varargin(1))==2
    figure(MU_FIG.PLOT)
    tmin=MU_DATA.TIME(MU_PLOT.TRANGE(1));
    tmax=MU_DATA.TIME(MU_PLOT.TRANGE(2));
    a=axis;
    axis([tmin tmax a(3) a(4)])
end    
if isempty(varargin)
    a=axis;
    ytext=1.10;
    xtext=0.02;
    xlogo=1.07;
    blue=[.2 .2 .8];
    gray=[0.8 0.8 0.8];
    fsiz=11;
    
    text(xtext,ytext,[num2str(MU_DATA.NRUN) '   ' MU_DATA.SAMPLE ...
                        MU_DATA.TEMPERATURE ' ' MU_DATA.FIELD ...
                        ' ' MU_DATA.ORIENTATION] ...
         ,'fontsize',fsiz,'fontweight','demi','color',blue,...
         'units','normalized','clipping','off')
    fsizlab=20;
    text(xlogo,ytext,'\mu lab',...
         'fontsize',fsizlab,'fontweight','demi',...
         'fontname','Arial','color',blue,'units','normalized',...
         'clipping','off');
    text(xlogo-0.05,ytext-0.1,'Overlay plot',...
         'fontsize',fsiz,'fontweight','demi',...
         'color',blue,'units','normalized',...
         'clipping','off');

    X=0.82;
    Y=0.6;
    dY=0.07;
    Xtwidth=0.14;
    Ytwidth=0.05;
    tag='Clear';
    hclear = uicontrol('Parent',MU_FIG.PLOT,...
                       'Style','pushbutton','Backgroundcolor',gray,...
                       'String','Clear',...
                       'Tag',tag,...
                       'Callback',@Plot_CallBack,...
                       'Units','normalized',...
                       'Position',...
                       [X,Y,1.1*Xtwidth,Ytwidth]);    

    Y=Y-dY;
    tag='Load';
    hload1 = uicontrol('Parent',MU_FIG.PLOT,...
                       'Style','pushbutton','Backgroundcolor',gray,...
                       'String','Load',...
                       'Tag',tag,...
                       'Callback',@Plot_CallBack,...
                       'Units','normalized',...
                       'Position',...
                       [X,Y,1.1*Xtwidth,Ytwidth]);    
    

    tag='Load+';
    Y=Y-dY;
    hload2 = uicontrol('Parent',MU_FIG.PLOT,...
                      'Style','pushbutton','Backgroundcolor',gray,...
                      'String','Load+',...
                      'Tag',tag,...
                      'Callback',@Plot_CallBack,...
                       'Units','normalized',...
                      'Position',...
                      [X,Y,1.1*Xtwidth,Ytwidth]);    
    tag='Load-';
    Y=Y-dY;
    hload = uicontrol('Parent',MU_FIG.PLOT,...
                      'Style','pushbutton','Backgroundcolor',gray,...
                      'String','Load-',...
                      'Tag',tag,...
                      'Units','normalized',...
                      'Callback',@Plot_CallBack,...
                      'Position',...
                      [X,Y,1.1*Xtwidth,Ytwidth]);    
    Y=Y-dY;
    tag='Range';
    htxtrange = uicontrol('Parent',MU_FIG.PLOT,...
                          'Style','text',...
                          'String','Range',...
                          'Units','normalized',...
                          'Horizontalalignment','Center',...
                          'Position',...
                          [X,Y,Xtwidth,Ytwidth]);
    Y=Y-0.9*dY;
    hrange=uicontrol('Parent',MU_FIG.PLOT,...
                     'Style','Edit',...
                     'String',num2str(MU_PLOT.TRANGE),...
                     'Tag',tag,...
                     'Callback',@Plot_CallBack,...
                     'Horizontalalignment','Left',...
                     'Units','normalized',...
                     'Position',...
                     [X,Y,Xtwidth,Ytwidth],...
                     'Backgroundcolor','white');
    Y=Y-dY;
    tag='Quit';
    hquit=uicontrol('Parent',MU_FIG.PLOT,...
                    'Style','pushbutton',...
                    'String','Quit',...
                    'Tag',tag,...
                    'Callback',@Plot_CallBack,...
                    'Units','normalized',...
                    'Position',...
                    [X,Y,Xtwidth,Ytwidth],...
                    'Backgroundcolor','white');
end
set(MU_FIG.PLOT,'Visible','On');
    

function Plot_CallBack(varargin)
global MU_PLOT MU_DATA MU_FIG

handle=cell2mat(varargin(1));
switch get(handle,'Tag')
  case 'Clear'
    muload
    muplotover
  case 'Load'
    muload
    muplotover(1)
  case 'Load+'
    if mucanload(MU_DATA.NRUN+1)
        muload(1)
        muplotover(1)
    end
  case 'Load-'
    if mucanload(MU_DATA.NRUN-1)
        muload(-1)
        muplotover(1)
    end
  case 'Range'
    range=str2num(get(handle,'String'));
    if range(1)>=1 && range(2)<=size(MU_DATA.ASYMMETRY,2) &&...
                 range(2)>range(1)
        MU_PLOT.TRANGE=range;
        muplotover(2) % go back and simply issue an axis([]) to
                      % change range
    else
        set(handle,'String',num2str(MU_PLOT.TRANGE))
    end
  case 'Quit'
    n=MU_PLOT.NRUN_RESTORE - MU_DATA.NRUN;
    muload(n)
    muasymmetry
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'Visible','Off');
    mufit_gui(1) % bring back focus to menu
end