function musavechi2(model,fitspecs,runs,range)
% musavechi2(model,fitspecs,runs,range)
%
% Saves a mat file with spec .chi2 containing 
% range runs and their chi2 of model fit over the specified  range 
% 
% mulab .fit and .log filenames have the following syntax: model.run_number.fitspecs.log
% e.g                                             'mumuba.2345.2\:3-1+4_1.log'
%
% model = string containing model name, e.g. 'mumuba'
% fitspecs = string containing detectors and version, 
%            mind the special characters, such as ":" that must be written "\:"
% runs = number array of run numbers without leading zeros
% range = start bin final bin for fit, as in PlotFit, mufit GUI

global MU_PATH
global MU_MODEL_F MU_MODEL
global MU_TEMP

% bookkeeping
MU_TEMP=MU_MODEL_F; % temporary store

% save present run
global MU_DATA
oldrun=MU_DATA.NRUN; % store run number according to mufit_gui records

% model loading from .fit files follows roughly muldmodel 
chi2=[];
try
  for kk= 1:length(runs)  % main loop through runs
    clear global MU_MODEL_F MU_MODEL
    global MU_MODEL_F MU_MODEL
    filename = [MU_PATH.LOG model '.' int2str(runs(kk)) '.' fitspecs];

    load([filename  '.fit'],'-mat') % expects to find one .fit file for each selected run, aborts if one is missing 

%    MU_MODEL_F.RANGE=range; % sets specific range

    if isfield(MU_MODEL_F,'NAME') % check for compatibility
                                      % with old version, will disappear
       MU_MODEL.NAME=MU_MODEL_F.NAME;
    else
       MU_MODEL.NAME=model; % name from input
    end
    MU_MODEL.COMPONENTNUMBER=MU_MODEL_F.COMPONENTNUMBER;
    MU_MODEL.ALPHA=MU_MODEL_F.ALPHA;
    MU_MODEL.FLAG=MU_MODEL_F.FLAG;
    MU_MODEL.BATCHMODE=MU_MODEL_F.BATCHMODE;
    MU_MODEL.GROUPING=MU_MODEL_F.GROUPING;
    MU_MODEL.RANGE=MU_MODEL_F.RANGE;
    MU_MODEL.BIN=MU_MODEL_F.BIN;
    MU_MODEL.COMPONENT=MU_MODEL_F.COMPONENT;
    if ~isfield(MU_MODEL_F.FLAG,'LOGVERSION')
        MU_MODEL_F.FLAG.LOGVERSION=1;
        MU_MODEL.FLAG.LOGVERSION=1;
    end
    if isfield(MU_MODEL_F,'NRUN')
        MU_MODEL.NRUN=MU_MODEL_F.NRUN; % this is not necessarily the fitted run, could be the run of a reloaded model
    end

% load data
    MU_DATA.NRUN=runs(kk);
    muload(0) % loads run MU_DATA.NRUN  
    global MU_DATA  % must be redeclared because muload altered it
% now calculate chi2, below is a subportion of mufit
    muasymmetry % refreshes asymmetry
    data=[MU_DATA.TIME(range(1):range(2)); ...
          MU_DATA.ASYMMETRY(range(1):range(2)); ...
          MU_DATA.ASYMERROR(range(1):range(2))];

% find out znpin stpbnd parnames
    [znpin stpbnd parname pf]=mupar(1); % use MU_MODEL
    parnames=[];
    for k=1:length(parname);
        parnames=[parnames ' ' cell2mat(parname(k))];
    end
    parnames=parnames(2:end); % remove starting blank
   
% recalculates array MU_MODEL.COMPONENT(k).SHARE to redistribute parameters
% and MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT for linear relations

    muprofcn 

% execute FMINUIT

    [znpout,znepout,chi]=fminuit('mufcn','mnplot',znpin,data, ...
                                 '-s',stpbnd,'-c','exit',...
                                 '-n',parnames);

% calculate

    nu=length(data(1,:))-(length(znpin)-pf); % degrees of freedom
    chi2=[chi2 chi/nu];

  end % main loop through runs
% open a new mat file called model.fitspecs.chi2 and save range, runs and chi2, array with value of chi2 for each run in run
 
  save([filename '.chi2'],'range','runs','chi2','-mat');
  disp(['Chi2 for runs:' num2str(runs)])
  disp(['saved in mat file ' filename '.chi2']) 
  disp(' ')
% copy back from TEMP to MODEL_F and MODEL
  clear global MU_MODEL_F MU_MODEL
  global MU_MODEL_F MU_MODEL
  MU_MODEL_F=MU_TEMP;
  clear global MU_TEMP

  MU_MODEL.NAME=MU_MODEL_F.NAME; % name from input
        
  MU_MODEL.COMPONENTNUMBER=MU_MODEL_F.COMPONENTNUMBER;
  MU_MODEL.ALPHA=MU_MODEL_F.ALPHA;
  MU_MODEL.FLAG=MU_MODEL_F.FLAG;
  MU_MODEL.BATCHMODE=MU_MODEL_F.BATCHMODE;
  MU_MODEL.GROUPING=MU_MODEL_F.GROUPING;
  MU_MODEL.RANGE=MU_MODEL_F.RANGE;
  MU_MODEL.BIN=MU_MODEL_F.BIN;
  MU_MODEL.COMPONENT=MU_MODEL_F.COMPONENT;
  if isfield(MU_MODEL_F,'NRUN')
     MU_MODEL.NRUN=MU_MODEL_F.NRUN;
  end

%reload data
  global MU_DATA
  MU_DATA.NRUN=oldrun;
  muload(0)
% that's all

catch error
  disp(['musavechi2 was not completed and ended with the following ERROR MESSAGE: ' error.identifier]) 
  disp(['Filename = ' filename ', run number = ' int2str(runs(kk))])
  %length(data)
end  



