function musavemodel(varargin)
% usage musavemodel
%
% offers gui to save file by the name e.g. babamu.fit:
% bare models containing only the structure MU_MODEL 
%
% usage musavemodel(1)
% 
% (internal use) saves 
% a -mat file with everything from the fit, e.g.
% mubaba.5234.3-4_1.fit        (note the unconventional
% extension) 
% Can load with load(filename,'-mat')   or    load -mat filename
%
% model name, .run number, .grouping tag, _log version tag
% Contains the structure MU_MODEL_F with fit results
%
% See also MUPATH, MULOAD, MUSET, MUMODEL, MUFITMENU, MUFIT,
% MUSAVEMODEL, MURIG, MULABSAVE, MULIST, MUPLOT
%
% HELP MU for a list,  

global MU_MODEL MU_DATA MU_PATH MU_GEAR
global MU_ADD
if isfield(MU_MODEL,'NAME')
%     if isfield(MU_DATA,'NRUN')
%         mu_data.run=MU_DATA.NRUN;
%         mu_data.zeropad=MU_DATA.ZEROPAD;
%         mu_data.resns=MU_DATA.RESNS;
%         mu_data.start_date=MU_DATA.START_DATE;
%         mu_data.stop_date=MU_DATA.STOP_DATE;
%         mu_data.start_time=MU_DATA.START_TIME;
%         mu_data.stop_time=MU_DATA.STOP_TIME;
%         mu_data.title=MU_DATA.TITLE;
%         mu_data.sample=MU_DATA.SAMPLE;
%         mu_data.orientation=MU_DATA.ORIENTATION;
%         mu_data.temperature=MU_DATA.TEMPERATURE;
%         mu_data.field=MU_DATA.FIELD;
%         mu_data.B=str2num(MU_DATA.FIELD(1:end-1));
%         mu_data.T=str2num(MU_DATA.TEMPERATURE(1:end-1));
%     end

    if ~isempty(varargin) % save model and fit results
        global MU_MODEL_F
        
        if isfield(MU_DATA,'NRUN') % check that a file was loaded
            if ~isempty(MU_DATA.NRUN)
                srun=num2str(MU_DATA.NRUN);
                %if ~isempty(MU_ADD)
                %    arun=num2str(MU_ADD(1));
                %    for k=2:length(MU_ADD)
                %       arun=[arun '+' num2str(MU_ADD(k))];
                %    end
                %    srun=[srun '+' arun];
                %end
                if ispc
                    slash='\';
                elseif isunix 
                    slash='/';
                else
                    'Sorry, mulab is not available yet for your OS';
                end

                if MU_PATH.LOG(end)~=slash
                    MU_PATH.LOG=[MU_PATH.LOG slash];
                end  
                filename=MU_PATH.LOG;
                
                if isfield(MU_MODEL.FLAG,'LOGVERSION')
                    % New fixed version 
                    filename=[filename char(MU_MODEL.NAME) ...
                              '.' srun '.' mugrouptag '_' ];
                    filename=[filename ...
                                 MU_MODEL.FLAG.LOGVERSION '.fit'];
                else
                    % Old incremental version
                    n=1;
                    filename=[filename char(MU_MODEL.NAME) ...
                              '.' srun '.' mugrouptag '_' ];
                    filenametmp=[filename int2str(n) '.fit'];
                    ok=exist(filenametmp);
                    while ok
                        n=n+1;
                        filenametmp=[filename int2str(n) '.fit'];
                        ok=exist(filenametmp);
                    end
                    filename=filenametmp;
                end
                disp(['Saving best fit model into file ' filename])
                %                save(filename,'mu_data','MU_MODEL_F','-mat')
                save(filename,'MU_MODEL_F','-mat')
            else % a fit was attempted without data, do not save
                msgbox('No data, the fit aborted, no save','Save Model',...
                       'non-modal')
            end 
        end % this was internal use musavemodel(1), for fit results
    else %  save model only
         %
         % recalculate array SHARE which redistributes parameters
         % must have as many elements as the total number of parameters
         % but share(j) is the index of par inside fminuit 
         % where += parameters do not appear
        shareglobal=[];
        par=0;
        for k=1:MU_MODEL.COMPONENTNUMBER
            share=[]; % this is the component SHARE array
            for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER
                switch MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG
                  case {'~','!'}
                    par=par+1; % index is incremented only for ~! parameters
                    share=[share par];
                    shareglobal=[shareglobal par];
                  case '+'
                    share=[share 0];
                    shareglobal=[shareglobal 0];
                  case '=' % must be a preceding parameter
                    parshared=MU_MODEL.COMPONENT(k).PARAMETER(j).SHARE;
                    share=[share shareglobal(parshared)];
                    shareglobal=[shareglobal shareglobal(parshared)];
                end
            end
            %        disp (['comp=' num2str(k) ': ' num2str(share)])
            MU_MODEL.COMPONENT(k).SHARE=share;
        end
        if MU_PATH.LOG(end)==slash
            filename=MU_PATH.LOG;
        else
            filename=[MU_PATH.LOG slash];
        end  
        filename=[filename char(MU_MODEL.NAME) '.' mugrouptag '.fit'];
        disp(['Saving fit model into file ' filename])
        save(filename,'MU_MODEL','MU_GEAR','-mat')
    end
    
else
    disp('No model to save!')
end % exist MU_MODEL.NAME