function muset
% usage muset
% when starting analysis of a new run, calculates 
% MU_DATA.BACKGROUND, MU_DATA.NT0, MU_DATA.DT, MU_DATA.ET
% 
    

% new problem: HAL has 17 histos- much larger resolution, so the prompt is noisy
% and sometimes there are two or more equal maxima within it, so that the
% naive procedure to roughly localize it fails; - the initial parameters
% for the fit must be chosen differently; - plotting needs 16 slots in
% the graphic window

global MU_GEAR MU_TABLE MU_DATA MU_FIG
nt0=[];
dt=[];
et0=[];
back=[];
fsiz=14;
switch MU_GEAR.FACILITY
  case 'PSI'
    % must calculate prompts and background for each histo
    xl=0.12;yl=0.12;xw=0.4;yw=0.4;empty=[];nright=30;
    halfwidth=2; % prompt half width in bins
    defaults={'10','10','7'}; % for MU_GEAR.LBG .RBG .OFFSET
    goodhisto=1:min(size(MU_DATA.DATA,2),4); 
    good=[]; % search prompt in non empty histograms only 
    ax=zeros(1,4);
    if MU_GEAR.INSTRUMENT=='HAL'
        xl=0.08;yl=0.08;xw=0.22;yw=0.22;nright=200;
        halfwidth=20; % prompt half width in bins
        defaults={'10','40','40'}; % for MU_GEAR.LBG .RBG .OFFSET
        goodhisto=2:size(MU_DATA.DATA,2);
        ax=zeros(1,16);
    end   
    answer=inputdlg({'Left offset','Right offset','Fit offset'},...
                    'Background estimate',1,defaults);
    MU_GEAR.LBG=str2num(char(answer(1))); % left background is evaluated as
    MU_GEAR.RBG=str2num(char(answer(2))); % average between LBG and prompt-RBG
    MU_GEAR.OFFSET=str2num(char(answer(3))); % right average level
                                             % is evaluated as average between prompt+OFFSET and prompt+nright
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'name','determining t=0','menubar','figure')
    clf
    for histo=goodhisto % rite is always out
        if sum(MU_DATA.DATA(:,histo))>0 ; % histogram
            good=[good histo];
        end
        logical_histo=good;
        if MU_GEAR.INSTRUMENT=='HAL', logical_histo=good-1; end
    end
    for logical=logical_histo
        histo=logical; if  MU_GEAR.INSTRUMENT=='HAL', histo=logical+1; end
        switch logical
          case 1
            ax(1)=axes('position',[xl,yl,xw,yw]); % 1 1
            ylabel('counts')
            xlabel('bin')
          case 2    
            ax(2)=axes('position',[xl+xw,yl,xw,yw]); % 2 1
            xlabel('bin')
          case 3    
            ax(3)=axes('position',[xl,yl+yw,xw,yw]); % 1 2
            ylabel('counts')
          case 4
            ax(4)=axes('position',[xl+xw,yl+yw,xw,yw]); % 2 2
          case 5
            ax(5)=axes('position',[xl,yl+2*yw,xw,yw]); % 1 3
            ylabel('counts')
          case 6
            ax(6)=axes('position',[xl+xw,yl+2*yw,xw,yw]); % 2 3
          case 7
            ax(7)=axes('position',[xl,yl+3*yw,xw,yw]); % 1 4
            ylabel('counts')
          case 8
            ax(8)=axes('position',[xl+xw,yl+3*yw,xw,yw]); % 2 4
          case 9
            ax(9)=axes('position',[xl+2*xw,yl,xw,yw]); % 3 1
            xlabel('bin')
          case 10
            ax(10)=axes('position',[xl+3*xw,yl,xw,yw]); % 4 1
            xlabel('bin')
          case 11
            ax(11)=axes('position',[xl+2*xw,yl+yw,xw,yw]); % 3 2
          case 12
            ax(12)=axes('position',[xl+3*xw,yl+yw,xw,yw]); % 4 2
          case 13
            ax(13)=axes('position',[xl+2*xw,yl+2*yw,xw,yw]); % 3 3
          case 14
            ax(14)=axes('position',[xl+3*xw,yl+2*yw,xw,yw]); % 4 3
          case 15
            ax(15)=axes('position',[xl+2*xw,yl+3*yw,xw,yw]); % 3 4
          case 16
            ax(16)=axes('position',[xl+3*xw,yl+3*yw,xw,yw]); % 4 4
        end
        set(gca,'xticklabel',empty,'yticklabel',empty)
        set(gca,'Box','On')
        h=MU_DATA.DATA(:,histo); % histogram
        gnt0=find(h==max(h)); % prompt bin guess
        gnt0=gnt0(1); % to avoid more than one guess (HAL)
        first=find(h(1:end-1000), 1 )+MU_GEAR.LBG; % first bin for
                                                   % background
        %  find(condition,1) means first instance that obeys condition
        lastback=gnt0-MU_GEAR.RBG; % last bin for bakground guess
        last=gnt0+nright; % last bin for prompt fit
        %  determine prompt for each histogram
        %  fit starting guesses
        a(1)=halfwidth*h(gnt0); % Area guess
        a(2)=gnt0; % Center guess
        a(3)=halfwidth; % Sigma guess 
        a(4)=mean(h(first:lastback)); % BackLeft guess
        a(5)=mean(h(gnt0+MU_GEAR.OFFSET:gnt0+nright)); % BackRight guess
        X=first:last; % here the time array is in units of bins (first=1)
        eh=sqrt(h(X)'); 
        eh(find(~h(X)'))=1;
        data=[X; h(X)'; eh];
 % **** 
 % FIT
 % ***
        %
        disp(['histo = ',num2str(histo),' - logical = ',num2str(logical)])
        [a,ea,c]=fminuit('muprompt','mnplot',a,data,...
                         '-c','migr;exit');
        axes(ax(logical));
        hold(ax(logical),'all')
        x=gnt0-MU_GEAR.RBG:gnt0+nright;
        errorbar(x,h(x)',sqrt(h(x))','ro')
        plot(x,muprompt(a,x),'g-')
        aa=axis;
        %        if histo==2, axis([aa(1)+1 aa(2) aa(3) aa(4)]); end
        hnt0=round(a(2)); % here a is a real-value fit of the bin
                          % index, for the bin containing t=0
                      % If the t=0 fit yields 0.5<a<1.5, this
                      % correctly produces nt0=1
        hdt=(a(2)-hnt0)*MU_DATA.RESNS; % if the fitted position is
                                       % to the RIGHT of the bin
                                       % center this yields a
                                       % POSITIVE dt (shift FORWARD)
        text(x(1),aa(4)*0.9,['Histo ' int2str(logical)])
        text((x(end)+x(1))/2+10,aa(4)*0.85,['N_{t0}=' num2str(hnt0)])
        text((x(end)+x(1))/2+10,aa(4)*0.7,['\delta t=' num2str(hdt,2)])
        set(gca,'Box','On')        
        back=[back a(4)];
        nt0=[nt0 hnt0];
        dt=[dt hdt];
        et0=[et0 ea(2)*MU_DATA.RESNS];
    end
    coord=axis;
    text(coord(1)-60,1.05*coord(4),...
         ['{\fontsize{14} Prompts of } {\color[rgb]{0.1 0.2 0.8} ' ...
          MU_DATA.TITLE '}'],'fontweight','demi')
    switch MU_GEAR.INSTRUMENT
      case 'HAL'
        back=[0 back]; % fake first
        nt0=[0 nt0]; % fake first
        dt=[0 dt]; % fake first
        et0=[0 et0]; % fake first       
      otherwise
        back=[back 0]; % fake RITE
        nt0=[nt0 0]; % fake RITE
        dt=[dt 0]; % fake RITE
        et0=[et0 0]; % fake RITE
    end

  case 'ISIS'
    lengthdata=size(MU_DATA.DATA,1);
    h=sum(MU_DATA.DATA(1:lengthdata,:),2); % unweighted sum of all histo 
    error=sqrt(h); % ZN_DATA are counts, Poisson statistics
                   % if eN(:,i)=sqrt(N:,i)) then 
                   % sum(N,2) is also the square of its errors
    dh=(h(2:end)-h(1:end-1));  % numerical derivative
    nt0=find(dh==max(dh));
    error(find(~error))=1; % error ones where X are zeros
    pin=[(nt0-1)*MU_DATA.RESNS h(nt0+10)*MU_TABLE.TAUMU 80]; 
    % initial paramenter for t0, integral counts
    bins=[1:lengthdata]';
    t=(bins-1)*MU_DATA.RESNS; % raw times: center of first bin is t=0
                              % prompt (t=0) is  
                              % MU_DATA.NT0*MU_DATA.RESNS ns after 
                              % bin center, hence bin center is at 
                              % time -MU_DATA.NT0*MU_DATA.RESNS ns 
                              % (MU_DATA.DT is the average value)
    X=[t h(bins) error(bins)]'; %errors are weighted like X
    [p ep c]=fminuit('muedge','mnplot',pin,X,'-c','migr;exit');
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'Name','Determining t=0','MenuBAr','figure')
    clf
    hold(gca,'all')
    set(gca,'Box','On','Fontsize',fsiz)
    a=p(1)/MU_DATA.RESNS; % here ap(1) contains the raw time of the
                          % nt0 bin, conventionally (k-1)*RESNS
                          % where k is the bin index starting from 1
    nt0=round(a+0.5); % this is the bin containing t=0
                      % If t=0 coincided with a=zero+, t0 would be
                      % on the first bin, hence one must
                      % obtain nt0=1 
    dt=p(1)-(nt0-1)*MU_DATA.RESNS; % so dt is a shift FORWARD form
                                   % the nt0 bin center
    foreafter=30;
    if nt0-1<foreafter
        foreafter=nt0-1;
    end
    x=nt0-foreafter:nt0+foreafter;
    errorbar(x,h(x)',sqrt(h(x))','ro')
    tt=(x-1)*MU_DATA.RESNS;
    plot(x,muedge(p,tt),'g-')
    xlabel('Bins','Fontsize',fsiz)
    
    ylabel('Total counts, all detectors','Fontsize',fsiz) 
    p=axis;
    text(17,p(4)*1.02,[num2str(MU_DATA.NRUN) '  '...
                        ' ' MU_DATA.TITLE],'Fontsize',fsiz)
    text(12,p(4)*0.92,['NT0=' num2str(nt0) ', DT=' num2str(dt) ...
                   'ns'],'Fontsize',fsiz),
    N=[1 size(MU_DATA.DATA,2)];
    back=zeros(N);  % as many as the histos, all equal
    nt0=nt0*ones(N);                  % all equal
    dt=dt*ones(N);  % all equal
    et0=ep(1)*ones(N);                     % all equal
end
MU_DATA.BACKGROUND=back;
MU_DATA.NT0=nt0; 
MU_DATA.DT=dt;
MU_DATA.ET0=et0;    
MU_GEAR.NT0=nt0; % duplicate
MU_GEAR.DT=dt;   % duplicate
